[ Skip to Main Content ](https://www.servicenow.com/lpdem/demonow-all.html#main-content)
[ ![ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/servicenow-header-logo.svg) ![ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/servicenow-logo-icon.svg) ![ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/servicenow-header-logo-white.svg) ![ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/servicenow-logo-icon-white.svg) ](https://www.servicenow.com/)
* * *
  * ![Select your country](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/language-selector-light.svg)United States - Global Main menu


Search
![Clear Search](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/close-icon.svg)
Clear Search
![Search across ServiceNow](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/search-icon.svg)
![Close Search](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/close-icon.svg)
![Select your country](https://www.servicenow.com/content/dam/servicenow-assets/images/naas/language-selector-light.svg)
Americas
  * [United States - Global](https://www.servicenow.com/lpdem/demonow-all.html)
  * [Brasil - Português](https://www.servicenow.com/br/lpdem/demonow-all.html)
  * [Canada - Français](https://www.servicenow.com/fr-ca/lpdem/demonow-all.html)
  * [América Latina - Español](https://www.servicenow.com/latam/lpdem/demonow-all.html)


Asia, Pacific, and Japan
  * [日本 - 日本語](https://www.servicenow.com/jp/lpdem/demonow-all.html)
  * [한국 - 한국어](https://www.servicenow.com/kr/lpdem/demonow-all.html)
  * [Australia/NZ - English](https://www.servicenow.com/au/lpdem/demonow-all.html)
  * [India - English](https://www.servicenow.com/in/lpdem/demonow-all.html)


Europe, Middle East, and Africa
  * [United Kingdom - English](https://www.servicenow.com/uk/lpdem/demonow-all.html)
  * [DACH - Deutsch](https://www.servicenow.com/de/lpdem/demonow-all.html)
  * [France - Français](https://www.servicenow.com/fr/lpdem/demonow-all.html)
  * [Nederland - Nederlands](https://www.servicenow.com/nl/lpdem/demonow-all.html)
  * [España - Español](https://www.servicenow.com/es/lpdem/demonow-all.html)
  * [Italia - Italiano](https://www.servicenow.com/it/lpdem/demonow-all.html)


Created with Sketch.
## Recovery Email
Your account give you access to even more premium content, don't lose access to it. Provide a recovery email below.
  * Secondary E-mail


[Submit ](https://www.servicenow.com/lpdem/demonow-all.html##)
Demos  See how ServiceNow gets work done
### Solve your biggest challenges with ServiceNow. Learn how with easy-to-follow demos from our demo library.
  * Watch real workflows move from request to resolution.
  * Learn how one platform connects your entire enterprise stack.
  * See AI execute tasks across any department.


{"job_level":[{"value":"Individual Contributor","text":"Individual Contributor","nextField":"department","list":"common-departments"},{"value":"Developer/Engineer","text":"Developer/Engineer","nextField":"department","list":"common-departments"},{"value":"Architect","text":"Architect","nextField":"department","list":"common-departments"},{"value":"System Administrator","text":"System Administrator","nextField":"department","list":"common-departments"},{"value":"Manager/Sr","text":"Manager/Sr","nextField":"department","list":"common-departments"},{"value":"Director/Sr","text":"Director/Sr","nextField":"department","list":"common-departments"},{"value":"Vice President/SVP","text":"Vice President/SVP","nextField":"department","list":"common-departments"},{"value":"C-Level","text":"C-Level","nextField":"job_function"},{"value":"Press Analyst/Media","text":"Press Analyst/Media","alt":"press-other","nextField":"department","list":"press-analyst"}],"department":{"common-departments":[{"value":"Cloud Operations","text":"Cloud Operations","nextField":"job_function"},{"value":"Customer Service/Support","text":"Customer Service/Support","nextField":"job_function"},{"value":"Facilities","text":"Facilities","nextField":"job_function"},{"value":"Field Service","text":"Field Service","nextField":"job_function"},{"value":"Finance/Accounting","text":"Finance/Accounting","nextField":"job_function"},{"value":"Global Business Services/Shared Services","text":"Global Business Services/Shared Services","nextField":"job_function"},{"value":"Governance, Risk and Compliance","text":"Governance, Risk and Compliance","nextField":"job_function"},{"value":"HR","text":"HR","nextField":"job_function"},{"value":"IT","text":"IT","nextField":"job_function"},{"value":"Legal","text":"Legal","nextField":"job_function"},{"value":"Marketing","text":"Marketing","nextField":"job_function"},{"value":"Operations/Engineering/R\u0026D","text":"Operations/Engineering/R\u0026D","nextField":"job_function"},{"value":"Sales","text":"Sales","nextField":"job_function"},{"value":"Security","text":"Security","nextField":"job_function"},{"value":"Supply Chain/Manufacturing","text":"Supply Chain/Manufacturing","nextField":"job_function"}],"press-analyst":[{"value":"Other","text":"Other","alt":"press-other","nextField":"job_function","list":"press-other"}],"CEO":[{"value":"CEO","text":"CEO"}],"CIO":[{"value":"IT","text":"IT"}],"Operations":[{"value":"Operations/Engineering/R\u0026D","text":"Operations/Engineering/R\u0026D"}],"CISO/CSO":[{"value":"Security","text":"Security"}],"CHRO":[{"value":"HR","text":"HR"}],"CPO":[{"value":"Supply Chain/Manufacturing","text":"Supply Chain/Manufacturing"}],"CAIO":[{"value":"IT","text":"IT"}],"CDAO":[{"value":"IT","text":"IT"}],"CDO":[{"value":"Customer Service/Support","text":"Customer Service/Support"}],"CSCO":[{"value":"Supply Chain/Manufacturing","text":"Supply Chain/Manufacturing"}],"CMO":[{"value":"Marketing","text":"Marketing"}],"CRO":[{"value":"Governance, Risk and Compliance","text":"Governance, Risk and Compliance"}],"CRev":[{"value":"Sales","text":"Sales"}],"CFO":[{"value":"Finance/Accounting","text":"Finance/Accounting"}],"CCO":[{"value":"Customer Service/Support","text":"Customer Service/Support"}],"General Counsel":[{"value":"Legal","text":"Legal"}],"Other":[{"value":"Cloud Operations","text":"Cloud Operations"},{"value":"Customer Service/Support","text":"Customer Service/Support"},{"value":"Facilities","text":"Facilities"},{"value":"Field Service","text":"Field Service"},{"value":"Finance/Accounting","text":"Finance/Accounting"},{"value":"Global Business Services/Shared Services","text":"Global Business Services/Shared Services"},{"value":"Governance, Risk and Compliance","text":"Governance, Risk and Compliance"},{"value":"HR","text":"HR"},{"value":"IT","text":"IT"},{"value":"Legal","text":"Legal"},{"value":"Marketing","text":"Marketing"},{"value":"Operations/Engineering/R\u0026D","text":"Operations/Engineering/R\u0026D"},{"value":"Sales","text":"Sales"},{"value":"Security","text":"Security"},{"value":"Supply Chain/Manufacturing","text":"Supply Chain/Manufacturing"}]},"job_function":{"Artificial Intelligence":[{"value":"IT","text":"IT"}],"C-Level":[{"value":"CEO","text":"Chief Executive Officer","nextField":"department"},{"value":"CIO","text":"Chief Information Officer","nextField":"department"},{"value":"COO","text":"Chief Operating Officer","nextField":"department","list":"Operations"},{"value":"CPO","text":"Chief Product Officer","nextField":"department","list":"Operations"},{"value":"CISO/CSO","text":"Chief Information Security Officer","nextField":"department"},{"value":"CHRO","text":"Chief Human Resources Officer","nextField":"department"},{"value":"CDO","text":"Chief Digital Officer","nextField":"department"},{"value":"CPRO","text":"Chief Procurement Officer","nextField":"department","list":"CPO"},{"value":"CSCO","text":"Chief Supply Chain Officer","nextField":"department"},{"value":"CMO","text":"Chief Marketing Officer","nextField":"department"},{"value":"CRO","text":"Chief Risk Officer","nextField":"department"},{"value":"CRev","text":"Chief Revenue Officer","nextField":"department"},{"value":"CTO","text":"Chief Technology Officer","nextField":"department","list":"CIO"},{"value":"CFO","text":"Chief Financial Officer","nextField":"department"},{"value":"CAO","text":"Chief Accounting Officer","nextField":"department","list":"CFO"},{"value":"CCO","text":"Chief Customer Officer","nextField":"department"},{"value":"CComp","text":"Chief Compliance Officer","nextField":"department","list":"CRO"},{"value":"CLO","text":"Chief Legal Officer","nextField":"department","list":"General Counsel"},{"value":"CDAO","text":"Chief Data and Analytics Officer","nextField":"department"},{"value":"CAIO","text":"Chief Artificial Intelligence Officer","nextField":"department"},{"value":"General Counsel","text":"General Counsel","nextField":"department"},{"value":"Other","text":"Other","nextField":"department"}],"Cloud Operations":[{"value":"Cloud Operations","text":"Cloud Operations"}],"Customer Service/Support":[{"value":"Customer Experience Strategy","text":"Customer Experience Strategy"},{"value":"Customer Service Delivery/Management","text":"Customer Service Delivery/Management"},{"value":"Customer Service Operations","text":"Customer Service Operations"},{"value":"Customer Service Technology/Infrastructure","text":"Customer Service Technology/Infrastructure"},{"value":"Service/Support - Other","text":"Service/Support - Other"}],"Facilities":[{"value":"Facilities Service Delivery/Management","text":"Facilities Service Delivery/Management"},{"value":"Facilities Operations","text":"Facilities Operations"},{"value":"Facilities - Other","text":"Facilities - Other"}],"Field Service":[{"value":"Field Service Delivery/Management","text":"Field Service Delivery/Management"},{"value":"Field Service Technology/Infrastructure","text":"Field Service Technology/Infrastructure"},{"value":"Field Service - Other","text":"Field Service - Other"}],"Finance/Accounting":[{"value":"Accounting Shared Services","text":"Accounting Shared Services"},{"value":"Finance Projects/Operations","text":"Finance Projects/Operations"},{"value":"Financial Services Center","text":"Financial Services Center"},{"value":"T\u0026E/Credit Card Shared Services","text":"T\u0026E/Credit Card Shared Services"},{"value":"Finance - Other","text":"Finance - Other"}],"Governance, Risk and Compliance":[{"value":"Audit","text":"Audit"},{"value":"Compliance","text":"Compliance"},{"value":"Information Assurance","text":"Information Assurance"},{"value":"Privacy","text":"Privacy"},{"value":"Risk Management","text":"Risk Management"},{"value":"Vendor Risk","text":"Vendor Risk"},{"value":"GRC - Other","text":"GRC - Other"}],"HR":[{"value":"HR Business \u0026 Strategy","text":"HR Business \u0026 Strategy"},{"value":"HRIS/Global HRIS","text":"HRIS/Global HRIS"},{"value":"HR Operations","text":"HR Operations"},{"value":"HR Service Delivery/Management","text":"HR Service Delivery/Management"},{"value":"Payroll/Compensation Benefits","text":"Payroll/Compensation Benefits"},{"value":"Talent Management/Recruiting","text":"Talent Management/Recruiting"},{"value":"HR - Other","text":"HR - Other"}],"IT":[{"value":"Artificial Intelligence","text":"Artificial Intelligence"},{"value":"Application and Software Development","text":"Application and Software Development"},{"value":"Architecture","text":"Architecture"},{"value":"Datacenter Operations","text":"Datacenter Operations"},{"value":"DevOps","text":"DevOps"},{"value":"IT Asset Management","text":"IT Asset Management"},{"value":"IT Business Applications","text":"IT Business Applications"},{"value":"IT Business Management","text":"IT Business Management"},{"value":"IT Finance","text":"IT Finance"},{"value":"IT Infrastructure","text":"IT Infrastructure"},{"value":"IT Operations Management","text":"IT Operations Management"},{"value":"IT Service Management/Service Delivery","text":"IT Service Management/Service Delivery"},{"value":"IT Strategy","text":"IT Strategy"},{"value":"Project Management Office/PMO","text":"Project Management Office/PMO"},{"value":"Security","text":"Security"},{"value":"Service Desk/Help Desk","text":"Service Desk/Help Desk"},{"value":"Software Asset Management","text":"Software Asset Management"},{"value":"Vendor Management","text":"Vendor Management"},{"value":"IT - Other","text":"IT - Other"}],"Legal":[{"value":"Legal Operations","text":"Legal Operations"},{"value":"Legal - Other","text":"Legal - Other"}],"Supply Chain/Manufacturing":[{"value":"Operations","text":"Operations"},{"value":"Production Manager","text":"Production Manager"},{"value":"Engineer","text":"Engineer"},{"value":"Technician","text":"Technician"},{"value":"Supply Chain","text":"Supply Chain"},{"value":"Procurement","text":"Procurement"},{"value":"Analyst","text":"Analyst"},{"value":"Manufacturing - Other","text":"Manufacturing - Other"}],"Marketing":[{"value":"Marketing Operations","text":"Marketing Operations"},{"value":"Marketing Technology/Infrastructure","text":"Marketing Technology/Infrastructure"},{"value":"Marketing - Other","text":"Marketing - Other"}],"Operations/Engineering/R\u0026D":[{"value":"Application and Software Development","text":"Application and Software Development"},{"value":"Architecture","text":"Architecture"},{"value":"Product Management","text":"Product Management"},{"value":"Quality Assurance","text":"Quality Assurance"},{"value":"Product Support","text":"Product Support"},{"value":"Product Operations","text":"Product Operations"},{"value":"Program Management","text":"Program Management"},{"value":"Project Management","text":"Project Management"},{"value":"Op/Engineering/R\u0026D - Other","text":"Op/Engineering/R\u0026D - Other"}],"Sales":[{"value":"Sales Operations","text":"Sales Operations"},{"value":"Sales - Other","text":"Sales - Other"}],"Global Business Services/Shared Services":[{"value":"Line of Business IT","text":"Line of Business IT"},{"value":"Line of Business Operations","text":"Line of Business Operations"},{"value":"Line of Business Systems","text":"Line of Business Systems"},{"value":"Line of Business Service Enablement","text":"Line of Business Service Enablement"},{"value":"Shared Services Operations","text":"Shared Services Operations"},{"value":"Shared Services - Other","text":"Shared Services - Other"}],"Security":[{"value":"Incident Response","text":"Incident Response"},{"value":"Vulnerability","text":"Vulnerability"},{"value":"SOC","text":"SOC"},{"value":"Security Architect","text":"Security Architect"},{"value":"Security - Other","text":"Security - Other"}],"press-other":[{"value":"Other","text":"Other","alt":"press-other"}]},"iamInterestedIn":[{"display":"Accelerating accounts payable","value":"Accelerating accounts payable"},{"display":"Accelerating success with Impact","value":"Accelerating success with Impact"},{"display":"Accelerating time to quote","value":"Accelerating time to quote"},{"display":"AI-ready speed and scale with RaptorDB Pro","value":"AI-ready speed and scale with RaptorDB Pro"},{"display":"Aligning IT investments enterprise-wide","value":"Aligning IT investments enterprise-wide"},{"display":"Automating any workflow on a single AI platform","value":"Automating any workflow on a single AI platform"},{"display":"Automating order fulfillment","value":"Automating order fulfillment"},{"display":"Connecting any data for AI with Workflow Data Fabric","value":"Connecting any data for AI with Workflow Data Fabric"},{"display":"Creating intelligent apps with AI","value":"Creating intelligent apps with AI"},{"display":"Defending against security threats","value":"Defending against security threats"},{"display":"Delivering resilient IT services","value":"Delivering resilient IT services"},{"display":"Deploying autonomous AI agents","value":"Deploying autonomous AI agents"},{"display":"Freeing up employees from manual work","value":"Freeing up employees from manual work"},{"display":"Managing risk and compliance","value":"Managing risk and compliance"},{"display":"Minimizing IT asset costs and risks","value":"Minimizing IT asset costs and risks"},{"display":"Modernize revenue operations","value":"Modernize revenue operations"},{"display":"Modernizing workplace operations with AI","value":"Modernizing workplace operations with AI"},{"display":"Simplifying procurement operations","value":"Simplifying procurement operations"},{"display":"Streamlining field service operations","value":"Streamlining field service operations"},{"display":"Streamlining hire-to-retire processes with AI","value":"Streamlining hire-to-retire processes with AI"},{"display":"Streamlining supplier onboarding","value":"Streamlining supplier onboarding"},{"display":"Transforming customer service","value":"Transforming customer service"},{"display":"Visibility and reducing service outages","value":"Visibility and reducing service outages"}],"iWouldLikeTo":[{"display":"Speak With A ServiceNow Account Executive","value":"Speak with a ServiceNow Account Executive"},{"display":"Schedule Demo With ServiceNow Expert","value":"Schedule a demo with a ServiceNow expert"},{"display":"Learn More About Specific ServiceNow Applications","value":"Learn more about specific ServiceNow applications"},{"display":"Other","value":"Other"}],"demos":[{"title":"AI Agents","campaign-id":"224420","filter-value":"ai-agents"},{"title":"App Engine","campaign-id":"38118","filter-value":"app-engine"},{"title":"Configuration Management Database - CMDB","campaign-id":"101356","filter-value":"configuration-management-database"},{"title":"Customer Service Management","campaign-id":"9484","filter-value":"customer-service-management"},{"title":"Enterprise Asset Management","campaign-id":"97268","filter-value":"enterprise-asset-management"},{"title":"Environmental, Social, and Governance","campaign-id":"143406","filter-value":"environmental-social-and-governance"},{"title":"Field Service Management","campaign-id":"28782","filter-value":"field-service-management"},{"title":"Global Business Services","campaign-id":"82624","filter-value":"global-business-services"},{"title":"Governance, Risk, and Compliance","campaign-id":"19386","filter-value":"governance-risk-and-compliance"},{"title":"HR Service Delivery","campaign-id":"9482","filter-value":"hr-service-delivery"},{"title":"IT Asset Management","campaign-id":"17998","filter-value":"it-asset-management"},{"title":"IT Operations Management","campaign-id":"9488","filter-value":"it-operations-management"},{"title":"IT Service Management","campaign-id":"9487","filter-value":"it-service-management"},{"title":"Impact","campaign-id":"156022","filter-value":"impact"},{"title":"Legal Service Delivery","campaign-id":"29861","filter-value":"legal-service-delivery"},{"title":"Now Assist (GenAI)","campaign-id":"178163","filter-value":"now-assist"},{"title":"Now on Now","campaign-id":"31901","filter-value":"now-on-now"},{"title":"Sales and Order Management","campaign-id":"169275","filter-value":"sales-and-order-management"},{"title":"Security Operations","campaign-id":"9485","filter-value":"security-operations"},{"title":"ServiceNow AI Platform","campaign-id":"9481","filter-value":"application-development"},{"title":"Source-to-Pay Operations","campaign-id":"62891","filter-value":"procurement-service-management"},{"title":"Strategic Portfolio Management","campaign-id":"9486","filter-value":"strategic-portfolio-management"},{"title":"Technology Provider Service Management","campaign-id":"9486","filter-value":"technology-provider-service-management"},{"title":"Workflow Data Fabric","campaign-id":"83929","filter-value":"workflow-data-fabric"},{"title":"Workplace Service Delivery","campaign-id":"67990","filter-value":"workplace-service-delivery"},{"title":"Financial Services","campaign-id":"44971","filter-value":"financial-services"},{"title":"Government","campaign-id":"15265","filter-value":"government"},{"title":"Healthcare","campaign-id":"12907","filter-value":"healthcare"},{"title":"Manufacturing","campaign-id":"84151","filter-value":"manufacturing"},{"title":"Nonprofit","campaign-id":"161914","filter-value":"nonprofit"},{"title":"Telecommunications","campaign-id":"17999","filter-value":"telecommunications"}],"country":[{"text":"US - United States","value":"US"},{"text":"GB - United Kingdom","value":"GB","gdpr":"true"},{"text":"JP - Japan","value":"JP","gdpr":"true"},{"text":"FR - France","value":"FR","gdpr":"true"},{"text":"DE - Germany","value":"DE","gdpr":"true"},{"text":"AF - Afghanistan","value":"AF"},{"text":"AL - Albania","value":"AL"},{"text":"DZ - Algeria","value":"DZ"},{"text":"AS - American Samoa","value":"AS"},{"text":"AD - Andorra","value":"AD"},{"text":"AO - Angola","value":"AO"},{"text":"AI - Anguilla","value":"AI"},{"text":"AQ - Antarctica","value":"AQ"},{"text":"AG - Antigua and Barbuda","value":"AG"},{"text":"AR - Argentina","value":"AR","gdpr":"true"},{"text":"AM - Armenia","value":"AM"},{"text":"AW - Aruba","value":"AW"},{"text":"AU - Australia","value":"AU"},{"text":"AT - Austria","value":"AT","gdpr":"true"},{"text":"AZ - Azerbaijan","value":"AZ"},{"text":"BS - Bahamas","value":"BS"},{"text":"BH - Bahrain","value":"BH","gdpr":"true"},{"text":"BD - Bangladesh","value":"BD"},{"text":"BB - Barbados","value":"BB"},{"text":"BY - Belarus","value":"BY"},{"text":"BE - Belgium","value":"BE","gdpr":"true"},{"text":"BZ - Belize","value":"BZ"},{"text":"BJ - Benin","value":"BJ"},{"text":"BM - Bermuda","value":"BM"},{"text":"BT - Bhutan","value":"BT"},{"text":"BO - Bolivia","value":"BO"},{"text":"BA - Bosnia-Herzegovina","value":"BA"},{"text":"BW - Botswana","value":"BW"},{"text":"BR - Brazil","value":"BR","gdpr":"true"},{"text":"IO - British Indian Ocean Territory","value":"IO"},{"text":"VG - British Virgin Islands","value":"VG"},{"text":"BN - Brunei","value":"BN"},{"text":"BG - Bulgaria","value":"BG","gdpr":"true"},{"text":"BF - Burkina Faso","value":"BF"},{"text":"BI - Burundi","value":"BI"},{"text":"KH - Cambodia","value":"KH"},{"text":"CM - Cameroon","value":"CM"},{"text":"CA - Canada","value":"CA","gdpr":"true"},{"text":"CV - Cape Verde","value":"CV"},{"text":"KY - Cayman Islands","value":"KY"},{"text":"CF - Central African Republic","value":"CF"},{"text":"TD - Chad","value":"TD"},{"text":"CL - Chile","value":"CL"},{"text":"CN - China","value":"CN"},{"text":"CX - Christmas Island","value":"CX"},{"text":"CC - Cocos Islands","value":"CC"},{"text":"CO - Colombia","value":"CO"},{"text":"KM - Comoros","value":"KM"},{"text":"CG - Congo","value":"CG"},{"text":"CK - Cook Islands","value":"CK"},{"text":"CR - Costa Rica","value":"CR"},{"text":"CI - Cote d\u0027Ivoire","value":"CI"},{"text":"HR - Croatia","value":"HR","gdpr":"true"},{"text":"CW - Curacao","value":"CW"},{"text":"CY - Cyprus","value":"CY","gdpr":"true"},{"text":"CZ - Czech Republic","value":"CZ","gdpr":"true"},{"text":"CD - Democratic Republic of the Congo","value":"CD"},{"text":"DK - Denmark","value":"DK","gdpr":"true"},{"text":"DJ - Djibouti","value":"DJ"},{"text":"DM - Dominica","value":"DM"},{"text":"DO - Dominican Republic","value":"DO"},{"text":"TL - East Timor","value":"TL"},{"text":"EC - Ecuador","value":"EC"},{"text":"EG - Egypt","value":"EG"},{"text":"SV - El Salvador","value":"SV"},{"text":"GQ - Equatorial Guinea","value":"GQ"},{"text":"ER - Eritrea","value":"ER"},{"text":"EE - Estonia","value":"EE","gdpr":"true"},{"text":"ET - Ethiopia","value":"ET"},{"text":"FK - Falkland Islands","value":"FK"},{"text":"FO - Faroe Islands","value":"FO"},{"text":"FM - Federated States Of Micronesia","value":"FM"},{"text":"FJ - Fiji","value":"FJ"},{"text":"FI - Finland","value":"FI","gdpr":"true"},{"text":"GF - French Guiana","value":"GF"},{"text":"PF - French Polynesia","value":"PF"},{"text":"GA - Gabon","value":"GA"},{"text":"GM - Gambia","value":"GM"},{"text":"GE - Georgia","value":"GE"},{"text":"GH - Ghana","value":"GH"},{"text":"GI - Gibraltar","value":"GI"},{"text":"GR - Greece","value":"GR","gdpr":"true"},{"text":"GL - Greenland","value":"GL"},{"text":"GD - Grenada","value":"GD"},{"text":"GU - Guam","value":"GU"},{"text":"GT - Guatemala","value":"GT"},{"text":"GG - Guernsey","value":"GG"},{"text":"GN - Guinea","value":"GN"},{"text":"GW - Guinea-Bissau","value":"GW"},{"text":"GY - Guyana","value":"GY"},{"text":"HT - Haiti","value":"HT"},{"text":"HN - Honduras","value":"HN"},{"text":"HK - Hong Kong","value":"HK"},{"text":"HU - Hungary","value":"HU","gdpr":"true"},{"text":"IS - Iceland","value":"IS","gdpr":"true"},{"text":"IN - India","value":"IN"},{"text":"ID - Indonesia","value":"ID"},{"text":"IQ - Iraq","value":"IQ"},{"text":"IE - Ireland","value":"IE","gdpr":"true"},{"text":"IM - Isle of Man","value":"IM"},{"text":"IL - Israel","value":"IL","gdpr":"true"},{"text":"IT - Italy","value":"IT","gdpr":"true"},{"text":"JM - Jamaica","value":"JM"},{"text":"JE - Jersey","value":"JE"},{"text":"JO - Jordan","value":"JO"},{"text":"KZ - Kazakhstan","value":"KZ"},{"text":"KE - Kenya","value":"KE","gdpr":"true"},{"text":"KI - Kiribati","value":"KI"},{"text":"XK - Kosovo","value":"XK"},{"text":"KW - Kuwait","value":"KW"},{"text":"KG - Kyrgyzstan","value":"KG"},{"text":"LA - Laos","value":"LA"},{"text":"LV - Latvia","value":"LV","gdpr":"true"},{"text":"LB - Lebanon","value":"LB"},{"text":"LS - Lesotho","value":"LS"},{"text":"LR - Liberia","value":"LR"},{"text":"LY - Libya","value":"LY"},{"text":"LI - Liechtenstein","value":"LI","gdpr":"true"},{"text":"LT - Lithuania","value":"LT","gdpr":"true"},{"text":"LU - Luxembourg","value":"LU","gdpr":"true"},{"text":"MO - Macau","value":"MO"},{"text":"MK - Macedonia, Former Yugoslav Rep.","value":"MK"},{"text":"MG - Madagascar","value":"MG"},{"text":"MW - Malawi","value":"MW"},{"text":"MY - Malaysia","value":"MY"},{"text":"MV - Maldives","value":"MV"},{"text":"ML - Mali","value":"ML"},{"text":"MT - Malta","value":"MT","gdpr":"true"},{"text":"MH - Marshall Islands","value":"MH"},{"text":"MQ - Martinique","value":"MQ"},{"text":"MR - Mauritania","value":"MR"},{"text":"MU - Mauritius","value":"MU","gdpr":"true"},{"text":"YT - Mayotte","value":"YT"},{"text":"MX - Mexico","value":"MX"},{"text":"MD - Moldova","value":"MD"},{"text":"MC - Monaco","value":"MC"},{"text":"MN - Mongolia","value":"MN"},{"text":"ME - Montenegro","value":"ME"},{"text":"MS - Montserrat","value":"MS"},{"text":"MA - Morocco","value":"MA"},{"text":"MZ - Mozambique","value":"MZ"},{"text":"MM - Myanmar","value":"MM"},{"text":"NA - Namibia","value":"NA"},{"text":"NR - Nauru","value":"NR"},{"text":"NP - Nepal","value":"NP"},{"text":"NL - Netherlands","value":"NL","gdpr":"true"},{"text":"AN - Netherlands Antilles","value":"AN"},{"text":"NC - New Caledonia","value":"NC"},{"text":"NZ - New Zealand","value":"NZ","gdpr":"true"},{"text":"NI - Nicaragua","value":"NI"},{"text":"NE - Niger","value":"NE"},{"text":"NG - Nigeria","value":"NG","gdpr":"true"},{"text":"NU - Niue","value":"NU"},{"text":"MP - Northern Mariana Islands","value":"MP"},{"text":"NO - Norway","value":"NO","gdpr":"true"},{"text":"OM - Oman","value":"OM"},{"text":"PK - Pakistan","value":"PK"},{"text":"PW - Palau","value":"PW"},{"text":"PS - Palestine","value":"PS"},{"text":"PA - Panama","value":"PA"},{"text":"PG - Papua New Guinea","value":"PG"},{"text":"PY - Paraguay","value":"PY"},{"text":"PE - Peru","value":"PE"},{"text":"PH - Philippines","value":"PH"},{"text":"PN - Pitcairn","value":"PN"},{"text":"PL - Poland","value":"PL","gdpr":"true"},{"text":"PT - Portugal","value":"PT","gdpr":"true"},{"text":"PR - Puerto Rico","value":"PR"},{"text":"QA - Qatar","value":"QA","gdpr":"true"},{"text":"CG - Republic of the Congo","value":"CG"},{"text":"RE - Reunion","value":"RE"},{"text":"RO - Romania","value":"RO","gdpr":"true"},{"text":"RU - Russia","value":"RU"},{"text":"RW - Rwanda","value":"RW"},{"text":"BL - Saint Barthelemy","value":"BL"},{"text":"SH - Saint Helena","value":"SH"},{"text":"MF - Saint Martin","value":"MF"},{"text":"PM - Saint Pierre and Miquelon","value":"PM"},{"text":"VC - Saint Vincent and the Grenadines","value":"VC"},{"text":"WS - Samoa","value":"WS"},{"text":"SM - San Marino","value":"SM"},{"text":"ST - Sao Tome and PrÃ­ncipe","value":"ST"},{"text":"SA - Saudi Arabia","value":"SA"},{"text":"SN - Senegal","value":"SN"},{"text":"RS - Serbia","value":"RS"},{"text":"SC - Seychelles","value":"SC"},{"text":"SL - Sierra Leone","value":"SL"},{"text":"SG - Singapore","value":"SG"},{"text":"SX - Sint Maarten","value":"SX"},{"text":"SK - Slovakia","value":"SK","gdpr":"true"},{"text":"SI - Slovenia","value":"SI","gdpr":"true"},{"text":"SB - Solomon Islands","value":"SB"},{"text":"SO - Somalia","value":"SO"},{"text":"ZA - South Africa","value":"ZA","gdpr":"true"},{"text":"KR - South Korea","value":"KR","gdpr":"true"},{"text":"SS - South Sudan","value":"SS"},{"text":"ES - Spain","value":"ES","gdpr":"true"},{"text":"LK - Sri Lanka","value":"LK"},{"text":"KN - St. Kitts and Nevis","value":"KN"},{"text":"LC - St. Lucia","value":"LC"},{"text":"SD - Sudan","value":"SD"},{"text":"SR - Suriname","value":"SR"},{"text":"SJ - Svalbard and Jan Mayen","value":"SJ"},{"text":"SZ - Swaziland","value":"SZ"},{"text":"SE - Sweden","value":"SE","gdpr":"true"},{"text":"CH - Switzerland","value":"CH","gdpr":"true"},{"text":"TW - Taiwan","value":"TW"},{"text":"TJ - Tajikistan","value":"TJ"},{"text":"TZ - Tanzania","value":"TZ"},{"text":"TH - Thailand","value":"TH"},{"text":"TG - Togo","value":"TG"},{"text":"TK - Tokelau","value":"TK"},{"text":"TO - Tonga","value":"TO"},{"text":"TT - Trinidad and Tobago","value":"TT"},{"text":"TN - Tunisia","value":"TN"},{"text":"TR - Turkey","value":"TR","gdpr":"true"},{"text":"TM - Turkmenistan","value":"TM"},{"text":"TC - Turks and Caicos Islands","value":"TC"},{"text":"TV - Tuvalu","value":"TV"},{"text":"UG - Uganda","value":"UG","gdpr":"true"},{"text":"UA - Ukraine","value":"UA"},{"text":"AE - United Arab Emirates","value":"AE"},{"text":"UY - Uruguay","value":"UY","gdpr":"true"},{"text":"UZ - Uzbekistan","value":"UZ"},{"text":"VU - Vanuatu","value":"VU"},{"text":"VA - Vatican","value":"VA"},{"text":"VE - Venezuela","value":"VE"},{"text":"VN - Vietnam","value":"VN"},{"text":"VI - Virgin Islands (USA)","value":"VI"},{"text":"WF - Wallis and Futuna","value":"WF"},{"text":"EH - Western Sahara","value":"EH"},{"text":"YE - Yemen","value":"YE"},{"text":"ZM - Zambia","value":"ZM"},{"text":"ZW - Zimbabwe","value":"ZW"}],"state":{"US":[{"text":"AK - Alaska","value":"Alaska","code":"US-AK"},{"text":"AL - Alabama","value":"Alabama","code":"US-AL"},{"text":"AR - Arkansas","value":"Arkansas","code":"US-AR"},{"text":"AZ - Arizona","value":"Arizona","code":"US-AZ"},{"text":"CA - California","value":"California","code":"US-CA"},{"text":"CO - Colorado","value":"Colorado","code":"US-CO"},{"text":"CT - Connecticut","value":"Connecticut","code":"US-CT"},{"text":"DC - District Of Columbia","value":"District Of Columbia","code":"US-DC"},{"text":"DE - Delaware","value":"Delaware","code":"US-DE"},{"text":"FL - Florida","value":"Florida","code":"US-FL"},{"text":"GA - Georgia","value":"Georgia","code":"US-GA"},{"text":"HI - Hawaii","value":"Hawaii","code":"US-HI"},{"text":"IA - Iowa","value":"Iowa","code":"US-IA"},{"text":"ID - Idaho","value":"Idaho","code":"US-ID"},{"text":"IL - Illinois","value":"Illinois","code":"US-IL"},{"text":"IN - Indiana","value":"Indiana","code":"US-IN"},{"text":"KS - Kansas","value":"Kansas","code":"US-KS"},{"text":"KY - Kentucky","value":"Kentucky","code":"US-KY"},{"text":"LA - Louisiana","value":"Louisiana","code":"US-LA"},{"text":"MA - Massachusetts","value":"Massachusetts","code":"US-MA"},{"text":"MD - Maryland","value":"Maryland","code":"US-MD"},{"text":"ME - Maine","value":"Maine","code":"US-ME"},{"text":"MI - Michigan","value":"Michigan","code":"US-MI"},{"text":"MN - Minnesota","value":"Minnesota","code":"US-MN"},{"text":"MO - Missouri","value":"Missouri","code":"US-MO"},{"text":"MS - Mississippi","value":"Mississippi","code":"US-MS"},{"text":"MT - Montana","value":"Montana","code":"US-MT"},{"text":"NC - North Carolina","value":"North Carolina","code":"US-NC"},{"text":"ND - North Dakota","value":"North Dakota","code":"US-ND"},{"text":"NE - Nebraska","value":"Nebraska","code":"US-NE"},{"text":"NH - New Hampshire","value":"New Hampshire","code":"US-NH"},{"text":"NJ - New Jersey","value":"New Jersey","code":"US-NJ"},{"text":"NM - New Mexico","value":"New Mexico","code":"US-NM"},{"text":"NV - Nevada","value":"Nevada","code":"US-NV"},{"text":"NY - New York","value":"New York","code":"US-NY"},{"text":"OH - Ohio","value":"Ohio","code":"US-OH"},{"text":"OK - Oklahoma","value":"Oklahoma","code":"US-OK"},{"text":"OR - Oregon","value":"Oregon","code":"US-OR"},{"text":"PA - Pennsylvania","value":"Pennsylvania","code":"US-PA"},{"text":"RI - Rhode Island","value":"Rhode Island","code":"US-RI"},{"text":"SC - South Carolina","value":"South Carolina","code":"US-SC"},{"text":"SD - South Dakota","value":"South Dakota","code":"US-SD"},{"text":"TN - Tennessee","value":"Tennessee","code":"US-TN"},{"text":"TX - Texas","value":"Texas","code":"US-TX"},{"text":"UT - Utah","value":"Utah","code":"US-UT"},{"text":"VA - Virginia","value":"Virginia","code":"US-VA"},{"text":"VT - Vermont","value":"Vermont","code":"US-VT"},{"text":"WA - Washington","value":"Washington","code":"US-WA"},{"text":"WI - Wisconsin","value":"Wisconsin","code":"US-WI"},{"text":"WV - West Virginia","value":"West Virginia","code":"US-WV"},{"text":"WY - Wyoming","value":"Wyoming","code":"US-WY"},{"text":"AS - American Samoa","value":"American Samoa","code":"US-AS"},{"text":"GU - Guam","value":"Guam","code":"US-GU"},{"text":"FM - Federated States Of Micronesia","value":"Federated States Of Micronesia","code":"US-FM"},{"text":"MH - Marshall Islands","value":"Marshall Islands","code":"US-MH"},{"text":"MP - Northern Mariana Islands","value":"Northern Mariana Islands","code":"US-MP"},{"text":"PR - Puerto Rico","value":"Puerto Rico","code":"US-PR"},{"text":"PW - Palau","value":"Palau","code":"US-PW"},{"text":"VI - Virgin Islands","value":"Virgin Islands","code":"US-VI"}],"CA":[{"text":"AB - Alberta","value":"Alberta","code":"CA-AB"},{"text":"BC - British Columbia","value":"British Columbia","code":"CA-BC"},{"text":"MB - Manitoba","value":"Manitoba","code":"CA-MB"},{"text":"NB - New Brunswick","value":"New Brunswick","code":"CA-NB"},{"text":"NL - Newfoundland and Labrador","value":"Newfoundland and Labrador","code":"CA-NL"},{"text":"NS - Nova Scotia","value":"Nova Scotia","code":"CA-NS"},{"text":"NU - Nunavut","value":"NU","code":"CA-NU"},{"text":"NT - Northwest Territories","value":"NT","code":"CA-NT"},{"text":"ON - Ontario","value":"Ontario","code":"CA-ON"},{"text":"PE - Prince Edward Island","value":"Prince Edward Island","code":"CA-PE"},{"text":"QC - Quebec","value":"Quebec","code":"CA-QC"},{"text":"SK - Saskatchewan","value":"Saskatchewan","code":"CA-SK"},{"text":"YT - Yukon Territory","value":"YT","code":"CA-YT"}],"AU":[{"text":"ACT - Australian Capital Territory","value":"Australian Capital Territory","code":"AU-ACT"},{"text":"NSW - New South Wales","value":"New South Wales","code":"AU-NSW"},{"text":"NT - Northern Territory","value":"Northern Territory","code":"AU-NT"},{"text":"QLD - Queensland","value":"Queensland","code":"AU-QLD"},{"text":"SA - South Australia","value":"South Australia","code":"AU-SA"},{"text":"TAS - Tasmania","value":"Tasmania","code":"AU-TAS"},{"text":"VIC - Victoria","value":"Victoria","code":"AU-VIC"},{"text":"WA - Western Australia","value":"Western Australia","code":"AU-WA"}],"BR":[{"text":"AC - Acre","value":"Acre","code":"BR-AC"},{"text":"AL - Alagoas","value":"Alagoas","code":"BR-AL"},{"text":"AM - Amazon","value":"Amazon","code":"BR-AM"},{"text":"AP - Amapa","value":"Amapa","code":"BR-AP"},{"text":"BA - Bahia","value":"Bahia","code":"BR-BA"},{"text":"CE - Ceara","value":"Ceara","code":"BR-CE"},{"text":"DF - Brasilia","value":"Brasilia","code":"BR-DF"},{"text":"ES - Espirito Santo","value":"Espirito Santo","code":"BR-ES"},{"text":"GO - Goias","value":"Goias","code":"BR-GO"},{"text":"MA - Maranhao","value":"Maranhao","code":"BR-MA"},{"text":"MG - Minas Gerais","value":"Minas Gerais","code":"BR-MG"},{"text":"MS - Mato Grosso do Sul","value":"Mato Grosso do Sul","code":"BR-MS"},{"text":"MT - Mato Grosso","value":"Mato Grosso","code":"BR-MT"},{"text":"PA - Para","value":"Para","code":"BR-PA"},{"text":"PB - Paraiba","value":"Paraiba","code":"BR-PB"},{"text":"PE - Pernambuco","value":"Pernambuco","code":"BR-PE"},{"text":"PI - Piaui","value":"Piaui","code":"BR-PI"},{"text":"PR - Parana","value":"Parana","code":"BR-PR"},{"text":"RJ - Rio de Janeiro","value":"Rio de Janeiro","code":"BR-RJ"},{"text":"RN - Rio Grande do Norte","value":"Rio Grande do Norte","code":"BR-RN"},{"text":"RO - Rondonia","value":"Rondonia","code":"BR-RO"},{"text":"RR - Roraima","value":"Roraima","code":"BR-RR"},{"text":"RS - Rio Grande do Sul","value":"Rio Grande do Sul","code":"BR-RS"},{"text":"SC - Santa Catarina","value":"Santa Catarina","code":"BR-SC"},{"text":"SE - Sergipe","value":"Sergipe","code":"BR-SE"},{"text":"SP - Sao Paulo","value":"Sao Paulo","code":"BR-SP"},{"text":"TO - Tocantins","value":"Tocantins","code":"BR-TO"}],"CN":[{"text":"Anhui","value":"Anhui","code":"CN-AH"},{"text":"Beijing","value":"Beijing","code":"CN-BJ"},{"text":"Chongqing","value":"Chongqing","code":"CN-CQ"},{"text":"Fujian","value":"Fujian","code":"CN-FJ"},{"text":"Gansu","value":"Gansu","code":"CN-GS"},{"text":"Guangdong","value":"Guangdong","code":"CN-GD"},{"text":"Guangxi","value":"Guangxi","code":"CN-GX"},{"text":"Guizhou","value":"Guizhou","code":"CN-GZ"},{"text":"Hainan","value":"Hainan","code":"CN-HI"},{"text":"Hebei","value":"Hebei","code":"CN-HE"},{"text":"Heilongjiang","value":"Heilongjiang","code":"CN-HL"},{"text":"Henan","value":"Henan","code":"CN-HA"},{"text":"Hubei","value":"Hubei","code":"CN-HB"},{"text":"Hunan","value":"Hunan","code":"CN-HN"},{"text":"Jiangsu","value":"Jiangsu","code":"CN-JS"},{"text":"Jiangxi","value":"Jiangxi","code":"CN-JX"},{"text":"Jilin","value":"Jilin","code":"CN-JL"},{"text":"Liaoning","value":"Liaoning","code":"CN-LN"},{"text":"Nei Mongol","value":"Nei Mongol","code":"CN-NM"},{"text":"Ningxia","value":"Ningxia","code":"CN-NX"},{"text":"Qinghai","value":"Qinghai","code":"CN-QH"},{"text":"Shaanxi","value":"Shaanxi","code":"CN-SN"},{"text":"Shandong","value":"Shandong","code":"CN-SD"},{"text":"Shanghai","value":"Shanghai","code":"CN-SH"},{"text":"Shanxi","value":"Shanxi","code":"CN-SX"},{"text":"Sichuan","value":"Sichuan","code":"CN-SC"},{"text":"Tianjin","value":"Tianjin","code":"CN-TJ"},{"text":"Xinjiang","value":"Xinjiang","code":"CN-XJ"},{"text":"Xizang","value":"Xizang","code":"CN-XZ"},{"text":"Yunnan","value":"Yunnan","code":"CN-YN"},{"text":"Zhejiang","value":"Zhejiang","code":"CN-ZJ"}],"IN":[{"text":"Andaman and Nicobar Islands","value":"Andaman and Nicobar Islands","code":"IN-AN"},{"text":"Andhra Pradesh","value":"Andhra Pradesh","code":"IN-AP"},{"text":"Arunachal Pradesh","value":"Arunachal Pradesh","code":"IN-AR"},{"text":"Assam","value":"Assam","code":"IN-AS"},{"text":"Bihar","value":"Bihar","code":"IN-BR"},{"text":"Chandigarh","value":"Chandigarh","code":"IN-CH"},{"text":"Chhattisgarh","value":"Chhattisgarh","code":"IN-CG"},{"text":"Dadra and Nagar Haveli","value":"Dadra and Nagar Haveli","code":"IN-DH"},{"text":"Daman and Diu","value":"Daman and Diu","code":"IN-DH"},{"text":"Goa","value":"Goa","code":"IN-GA"},{"text":"Gujarat","value":"Gujarat","code":"IN-GJ"},{"text":"Haryana","value":"Haryana","code":"IN-HR"},{"text":"Himachal Pradesh","value":"Himachal Pradesh","code":"IN-HP"},{"text":"Jammu and Kashmir","value":"Jammu and Kashmir","code":"IN-JK"},{"text":"Jharkhand","value":"Jharkhand","code":"IN-JH"},{"text":"Karnataka","value":"Karnataka","code":"IN-KA"},{"text":"Kerala","value":"Kerala","code":"IN-KL"},{"text":"Lakshadweep","value":"Lakshadweep","code":"IN-LD"},{"text":"Ladakh","value":"Ladakh","code":"IN-LA"},{"text":"Madhya Pradesh","value":"Madhya Pradesh","code":"IN-MP"},{"text":"Maharashtra","value":"Maharashtra","code":"IN-MH"},{"text":"Manipur","value":"Manipur","code":"IN-MN"},{"text":"Meghalaya","value":"Meghalaya","code":"IN-ML"},{"text":"Mizoram","value":"Mizoram","code":"IN-MZ"},{"text":"Nagaland","value":"Nagaland","code":"IN-NL"},{"text":"New Delhi","value":"New Delhi","code":"IN-DL"},{"text":"Odisha","value":"Odisha","code":"IN-OD"},{"text":"Puducherry","value":"Puducherry","code":"IN-PY"},{"text":"Punjab","value":"Punjab","code":"IN-PB"},{"text":"Rajasthan","value":"Rajasthan","code":"IN-RJ"},{"text":"Sikkim","value":"Sikkim","code":"IN-SK"},{"text":"Tamil Nadu","value":"Tamil Nadu","code":"IN-TN"},{"text":"Telangana","value":"Telangana","code":"IN-TS"},{"text":"Tripura","value":"Tripura","code":"IN-TR"},{"text":"Uttar Pradesh","value":"Uttar Pradesh","code":"IN-UP"},{"text":"Uttarakhand","value":"Uttarakhand","code":"IN-UK"},{"text":"West Bengal","value":"West Bengal","code":"IN-WB"}]}}
## Browse our demo library
[Sign in to existing account.](https://www.servicenow.com/lpdem/demonow-all.html)
undefined
Business E-mail
First Name
Last Name
Company
Phone Number
Job Level Individual Contributor Developer/Engineer Architect System Administrator Manager/Sr Director/Sr Vice President/SVP C-Level Press Analyst/Media
Job Function
undefined
Department
Job Function
Country US - United States GB - United Kingdom JP - Japan FR - France DE - Germany AF - Afghanistan AL - Albania DZ - Algeria AS - American Samoa AD - Andorra AO - Angola AI - Anguilla AQ - Antarctica AG - Antigua and Barbuda AR - Argentina AM - Armenia AW - Aruba AU - Australia AT - Austria AZ - Azerbaijan BS - Bahamas BH - Bahrain BD - Bangladesh BB - Barbados BY - Belarus BE - Belgium BZ - Belize BJ - Benin BM - Bermuda BT - Bhutan BO - Bolivia BA - Bosnia-Herzegovina BW - Botswana BR - Brazil IO - British Indian Ocean Territory VG - British Virgin Islands BN - Brunei BG - Bulgaria BF - Burkina Faso BI - Burundi KH - Cambodia CM - Cameroon CA - Canada CV - Cape Verde KY - Cayman Islands CF - Central African Republic TD - Chad CL - Chile CN - China CX - Christmas Island CC - Cocos Islands CO - Colombia KM - Comoros CG - Congo CK - Cook Islands CR - Costa Rica CI - Cote d'Ivoire HR - Croatia CW - Curacao CY - Cyprus CZ - Czech Republic CD - Democratic Republic of the Congo DK - Denmark DJ - Djibouti DM - Dominica DO - Dominican Republic TL - East Timor EC - Ecuador EG - Egypt SV - El Salvador GQ - Equatorial Guinea ER - Eritrea EE - Estonia ET - Ethiopia FK - Falkland Islands FO - Faroe Islands FM - Federated States Of Micronesia FJ - Fiji FI - Finland GF - French Guiana PF - French Polynesia GA - Gabon GM - Gambia GE - Georgia GH - Ghana GI - Gibraltar GR - Greece GL - Greenland GD - Grenada GU - Guam GT - Guatemala GG - Guernsey GN - Guinea GW - Guinea-Bissau GY - Guyana HT - Haiti HN - Honduras HK - Hong Kong HU - Hungary IS - Iceland IN - India ID - Indonesia IQ - Iraq IE - Ireland IM - Isle of Man IL - Israel IT - Italy JM - Jamaica JE - Jersey JO - Jordan KZ - Kazakhstan KE - Kenya KI - Kiribati XK - Kosovo KW - Kuwait KG - Kyrgyzstan LA - Laos LV - Latvia LB - Lebanon LS - Lesotho LR - Liberia LY - Libya LI - Liechtenstein LT - Lithuania LU - Luxembourg MO - Macau MK - Macedonia, Former Yugoslav Rep. MG - Madagascar MW - Malawi MY - Malaysia MV - Maldives ML - Mali MT - Malta MH - Marshall Islands MQ - Martinique MR - Mauritania MU - Mauritius YT - Mayotte MX - Mexico MD - Moldova MC - Monaco MN - Mongolia ME - Montenegro MS - Montserrat MA - Morocco MZ - Mozambique MM - Myanmar NA - Namibia NR - Nauru NP - Nepal NL - Netherlands AN - Netherlands Antilles NC - New Caledonia NZ - New Zealand NI - Nicaragua NE - Niger NG - Nigeria NU - Niue MP - Northern Mariana Islands NO - Norway OM - Oman PK - Pakistan PW - Palau PS - Palestine PA - Panama PG - Papua New Guinea PY - Paraguay PE - Peru PH - Philippines PN - Pitcairn PL - Poland PT - Portugal PR - Puerto Rico QA - Qatar CG - Republic of the Congo RE - Reunion RO - Romania RU - Russia RW - Rwanda BL - Saint Barthelemy SH - Saint Helena MF - Saint Martin PM - Saint Pierre and Miquelon VC - Saint Vincent and the Grenadines WS - Samoa SM - San Marino ST - Sao Tome and PrÃ­ncipe SA - Saudi Arabia SN - Senegal RS - Serbia SC - Seychelles SL - Sierra Leone SG - Singapore SX - Sint Maarten SK - Slovakia SI - Slovenia SB - Solomon Islands SO - Somalia ZA - South Africa KR - South Korea SS - South Sudan ES - Spain LK - Sri Lanka KN - St. Kitts and Nevis LC - St. Lucia SD - Sudan SR - Suriname SJ - Svalbard and Jan Mayen SZ - Swaziland SE - Sweden CH - Switzerland TW - Taiwan TJ - Tajikistan TZ - Tanzania TH - Thailand TG - Togo TK - Tokelau TO - Tonga TT - Trinidad and Tobago TN - Tunisia TR - Turkey TM - Turkmenistan TC - Turks and Caicos Islands TV - Tuvalu UG - Uganda UA - Ukraine AE - United Arab Emirates UY - Uruguay UZ - Uzbekistan VU - Vanuatu VA - Vatican VE - Venezuela VN - Vietnam VI - Virgin Islands (USA) WF - Wallis and Futuna EH - Western Sahara YE - Yemen ZM - Zambia ZW - Zimbabwe
State
I am interested in AI Agents App Engine Configuration Management Database - CMDB Customer Service Management Enterprise Asset Management Environmental, Social, and Governance Field Service Management Global Business Services Governance, Risk, and Compliance HR Service Delivery IT Asset Management IT Operations Management IT Service Management Impact Legal Service Delivery Now Assist (GenAI) Now on Now Sales and Order Management Security Operations ServiceNow AI Platform Source-to-Pay Operations Strategic Portfolio Management Technology Provider Service Management Workflow Data Fabric Workplace Service Delivery Financial Services Government Healthcare Manufacturing Nonprofit Telecommunications
I would like to hear about upcoming events, products and services from ServiceNow. I understand I can unsubscribe any time.
Yes
No
I want to create a ServiceNow account, which allows me to sign in and see premium content without filling out another form.
Signing up is simple. We’ll send you an email with instructions and a temporary password to complete your account.
undefined
I have read and agree to the ServiceNow Terms of Use and understand that my personal information is processed in accordance with  Privacy Statement.
ServiceNow® Website Terms of Use
##### 1. Acceptance of the Terms of Use
The following terms and conditions, together with any referenced documents (collectively, **"Terms of Use"**) are a legal agreement between you and your employees, agents, contractors and any other entity on whose behalf you accept these terms (collectively, “**you** ” and “**your** ”), and ServiceNow, Inc. if your domicile is within the USA, Canada or Mexico, or ServiceNow Nederland B.V. if your domicile is within any other country (“**ServiceNow** ,” “**we** ,” “**us** ” and “**our** ”). The Terms of Use apply to ServiceNow’s Website (as defined below).
**IMPORTANT: THESE TERMS OF USE FORM A BINDING CONTRACT BETWEEN YOU AND US WHEN ACCEPTED BY YOU. YOU ACCEPT THESE TERMS OF USE BY (1) ACCESSING OR USING THE WEBSITE, (2) INDICATING ACCEPTANCE OF THESE TERMS WHEN THEY ARE PRESENTED ONLINE, SUCH AS BY CHECKING A BOX CAPTIONED WITH ACCEPTANCE LANGUAGE OR CLICKING AN ICON BEARING AN “ACCEPT” OR SIMILAR LEGEND OR BY OTHERWISE ELECTRONICALLY SIGNING THIS AGREEMENT; OR (3) EXERCISING OR PURPORTING TO EXERCISE ANY OF THE RIGHTS GRANTED TO YOU UNDER THESE TERMS OF USE. THE INDIVIDUAL ACCEPTING THIS AGREEMENT ON BEHALF OF AN ENTITY REPRESENTS THAT HE OR SHE HAS AUTHORITY TO REPRESENT THE ENTITY AND COMMIT FUNDS ON ITS BEHALF. IF YOU DO NOT AGREE TO THESE TERMS OF USE, YOU MAY NOT USE THE WEBSITE.**
The term “**Website** ” means ServiceNow public websites, including without limitation those found at the following URLs: www.servicenow.com; community.servicenow.com; knowledge.servicenow.com; demochannel.service‑now.com; wiki.servicenow.com; share.servicenow.com; partners.servicenow.com; store.servicenow.com; publisher.servicenow.com; and developer.servicenow.com. The term “Website” does not include the ServiceNow Products (as defined below) regardless of the domain name used to access such ServiceNow Products.
The Website provides several types of resources, including one or more of the following: areas to interact with the Website and the user community such as message boards, chat rooms, forums, bulletin boards, training modules, user ratings, user reviews, and other related interactive and social features (collectively, the “**Community Services** ”); information, software, text, displays, images, video, audio recordings, and user interfaces included in or generated by the Website, and the design, selection and arrangement thereof, except that provided expressly and conspicuously under a third‑party license (collectively, the “**Website Content** ”); product specifications and product documentation (collectively, “**Documentation** ”); software such as application program interfaces, update sets, development tools, code snippets and sample code, not including Apps (defined below), published by ServiceNow to permit customization and configuration of ServiceNow Products (collectively, “**Development Tools** ”); and non‑production instances of the ServiceNow Products (“**Non‑Production Instances** ”). Your right to use of the Website, including Community Services, Website Content, Documentation, Development Tools and Non‑Production Instances, is subject to and conditioned on your acceptance of these Terms of Use.
We may revise and update these Terms of Use from time to time in our sole discretion. You are expected to check this page from time to time to take notice of any changes we made, as they are binding on you. All material changes apply prospectively only. Changes to the dispute resolution procedures set forth in the section titled  _Governing Law and Jurisdiction_ shall not apply to disputes for which the parties had actual notice as of the date the change was posted on the Website. Your continued use of the Website following the posting of revised Terms of Use means that you accept and agree to the changes. When accepted by you, the revised Terms of Use automatically revoke any license or other rights that we granted to you under the prior version.
Personally identifiable information collected about you by this Website is treated in accordance with the [Privacy Policy](https://www.servicenow.com/privacy-statement.html), which is hereby incorporated into these Terms of Use by reference. If you do not agree to these Terms of Use or the [Privacy Policy](https://www.servicenow.com/privacy-statement.html), you must exit the Website.
**Access**
We reserve the right to terminate or modify the Website including any of its content, in whole or in part, in any manner in our sole discretion, without notice. We will not be liable if, for any reason, all or any part of the Website is unavailable at any time or for any period. From time to time, we may restrict access to all or part of the Website to registered users or another subset of users. You are solely responsible for making all arrangements necessary for you to access the Website.
**Accounts**
To access portions of the Website or certain resources, you may be asked to provide certain registration details or other information. It is a condition of your use of the Website, and you hereby represent and warrant, that you are of the legal age of majority in the jurisdiction in which you reside and that all information you provide is correct, current and complete. If you choose, or you are provided with, a user name, password or other information as part of our security procedures, you must treat such information as confidential and you must not disclose it to any third party. You agree that you are solely responsible to us for all activities identified with your account. You agree to immediately notify ServiceNow of any unauthorized use of your user name or password or any other breach of security. You must logout from your account at the end of each session. You should use particular caution when accessing your account from a public or shared computer so that others are not able to view or record your password or other personal information. ServiceNow has the absolute right to disable any user name or password, at any time, for any reason, including, if in our sole discretion we believe that you have failed to comply with any provision of these Terms of Use.
**ServiceNow Products**
The “Website” does not include ServiceNow Products. “**ServiceNow Product** ” means the ServiceNow platform and any ServiceNow applications or subscription services, including those customarily provided by us only to our paying customers, along with professional services, support, and maintenance, and any other products or services offered for sale by ServiceNow. ServiceNow Products do not include Non‑Production Instances or Apps (as defined below). You must purchase access to ServiceNow Products pursuant to a separate subscription or other agreement with ServiceNow (“**Subscription Agreement** ”).
#####  2. Use of the Website
**Posting**
You and other third‑party users of the Website may be permitted to post, submit, contribute, publish, display, make a available or transmit to others (hereinafter, "**post** ") content, materials or hosted applications (collectively, "**User Contributions** " and together with contributions officially posted by ServiceNow, “**Contributions** ”) on or through the Website. Posting permits our customers, partners, developers, prospective customers, employees and other interested parties to share information, exchange ideas, expertise and experience, ask questions, provide solutions, share technology advances and obtain product information. To foster a vibrant, thriving, and friendly community, we may enforce standards for appropriate content and prohibit uses antithetical to the intended community environment. User Contributions are considered non‑confidential and non‑proprietary, and you hereby grant to ServiceNow a perpetual, irrevocable, royalty‑free, fully‑paid, sublicensable, transferable, non‑exclusive, worldwide license to copy, distribute, modify, make derivative works of, publicly display, publicly perform, make, use, sell, translate and disclose to third parties any User Contributions that you post for any purpose. We are under no obligation to post or use any User Contributions, and reserve the right to edit or remove User Contributions that violate these Terms of Use in our sole discretion.
To the extent you have purchased support rights under your Subscription Agreement, do not use Community Services for the escalation of support issues. Contact ServiceNow Support as provided in your Subscription Agreement.
You are solely responsible for any User Contribution that you post, including its legality, reliability, accuracy and appropriateness. ServiceNow is not responsible for (and has no liability with respect to) any User Contribution. You represent and warrant that you own or control all rights in and to the User Contributions that you post and have the right to grant ServiceNow and its affiliates the license granted above. You represent and warrant that all of your User Contributions do and will comply with these Terms of Use, and you agree to defend, indemnify and hold ServiceNow and its affiliates and licensors harmless for any breach of that representation and warranty. Opinions expressed in User Contributions are those of the party posting the User Contribution and do not necessarily reflect the opinion of ServiceNow.
**Code of Conduct**
You agree to comply with the following code of conduct in your use of the Website:
  * Be polite and courteous. Respect and treat others as you would expect to be treated yourself.
  * Respect your audience. Posts should not upset, annoy, threaten, harass, abuse or embarrass other members.
  * User Contributions may not include material that is defamatory, obscene, indecent, abusive, offensive, harassing, violent, hateful, inflammatory or otherwise objectionable.
  * Lively and collegial discussions are always encouraged in a healthy community. It is okay to argue facts but not okay to argue personalities or personal beliefs.
  * Do not use text formats such as all caps or bold that may be read as annoying, rude or send a strong message.
  * Avoid using abbreviations or terminology that others may not understand. An abbreviation may mean something to you but in another context or country, it may have another meaning.
  * Be accountable for your actions by correcting your mistakes and indicating where you have changed a previous post of yours.


**Prohibited Uses**
You agree not to access or use the Website in any manner:
  * That violates any applicable federal, state, local or international law or regulation, or advocates, promotes or assists in any unlawful act, constitutes an illegal threat or violates export control laws.
  * That violates the rights of any person or entity that may give rise to civil or criminal liability under applicable laws or regulations applicable to you, another user, and/or ServiceNow, including violation of privacy or publicity rights, infringement of any copyright, patent, trademark, trade secret or other intellectual property right, or conflicts with these Terms of Use or the Privacy Policy.
  * To transmit or introduce offensive materials, including those involving profanity, violence, sexual conduct, pornography or discrimination based on race, sex, religion, nationality, disability, sexual orientation or age.
  * To monitor or attempt to gain unauthorized access to: (a) an account or computer not belonging to you; (b) any data, information or communications on any network or system not owned by you, without authorization; (c) any system or network user accounts or passwords of other users, without authorization; or (d) e‑mail addresses, screen names or other identifiers without the consent of the person identified (including, without limitation, phishing, password robbery, spidering and harvesting).
  * That is false, deceptive, misleading or fraudulent, including but not limited to: (a) any attempt to impersonate any person or entity, including any other user, ServiceNow or a ServiceNow employee; (b) to misrepresent your identity or affiliation with any person or organization; and (c) any attempt to give the impression that you are posting materials from any person or entity other than yourself if that is not the case, including but not limited to altering your IP source address.
  * To use, transmit or introduce: (a) information protected under the privacy or security regulations issued pursuant to the Health Insurance Portability and Accountability Act of 1996 (HIPAA) or subject to the Health Information Technology for Economic and Clinical Health (HITECH) Act; or (b) non‑public sensitive or personally identifiable information including but not limited to drivers license numbers, passport numbers, social security numbers, tax identification numbers, voter registration numbers or similar identifying numbers, health information, or financial information including bank, checking, credit card, debit card, or other account numbers.
  * For the purposes of recruiting, advertising, solicitation or commercial activities of any kind without the express written consent of ServiceNow, including, but not limited to: (a) promotions, contests, sweepstakes, barter, advertising or pyramid schemes; and (b) the transmission of, or procurement of sending, any advertising or promotional material, including any "junk mail", "chain letter" or "spam" or any other similar solicitation.
  * To monitor or copy materials on the Website for any unauthorized purpose or access the Website via any automatic device, process or means of access such as a robot or spider.
  * That may have a detrimental effect on the Website’s function, user interaction or security, including but not limited to: (a) gaining unauthorized access to, or attempting to compromise the security of, any network, system, computing facility, equipment, data or information; (b) attempting to intercept, redirect or otherwise interfere with communications intended for others; (c) disabling, damaging, overburdening or impairing the Website or any server, computer or database connected to or accessed by the Website; (d) modifying, blocking or otherwise interfering with the display of the Website; (e) interfering with another user’s ability to access, use and enjoy the Website; (f) accessing another user’s registration information or user account without that user’s express written permission; (g) transmitting or introducing any malicious or technologically harmful element to the Website such as a spyware program, virus, Trojan horse, worm or logic bomb; (h) performing, without ServiceNow’s express prior written authorization, scalability testing, load testing, probing, scanning, penetration or vulnerability testing of the Website, including without limitation the Community Services; and (i) engaging in any activities that results in any server being the target of a denial of service attack.


**Notification of Violation.**
If you become aware of any violation of these Terms of Use by any person, including other users or third parties, you must immediately notify ServiceNow via e‑mail to info@servicenow.com.
**ServiceNow Disclaimer.**
We may, but are under no obligation to, monitor or censor comments made by users or content provided by contributors and we are not responsible for the accuracy, completeness, appropriateness or legality of anything posted, depicted or otherwise provided by third‑party users and we disclaim any and all liability relating thereto.
#####  3. Non-Production Instances
ServiceNow may provide you with temporary access to a non‑production instance of the ServiceNow Products upon your request to the Website (each a “**Non‑Production Instance** ”). Unless subject to a separate click‑accept agreement at the time of registration, access to and use of any and all Non‑Production Instances shall be governed by these Terms of Use, including without limitation the intellectual property and limitation of liability sections herein. If a click‑accept agreement is made available to you at the time of registration for access to ServiceNow services or products, then in the event of any conflict between that agreement and these Terms of Use, that agreement shall supersede these Terms of Use to the extent of the conflict.
Subject to compliance with these Terms of Use, ServiceNow authorizes you to access and use the Non‑Production Instance solely for your own internal use to evaluate the ServiceNow Products. ServiceNow may update, upgrade, add or remove plugins and functionality, and otherwise modify the Non‑Production Instance in its sole discretion without notice to you. Access to ServiceNow technical support resources is not provided with a Non‑Production Instance.
You may not use the Non‑Production Instance with production data or to provide services to others, including services of implementation, customization or configuration of the Subscription Service. You may not transfer, sublicense, distribute or otherwise provide third parties access to any applications, integrations or other material that you develop using the Non‑Production Instance. If you need to access the Subscription Service on a production basis or to provide services or develop Apps for others, please contact ServiceNow to discuss commercial offerings.
THE NON‑PRODUCTION INSTANCE AND OTHER SERVICENOW CORE TECHNOLOGY (AS DEFINED BELOW) ARE PROVIDED TO YOU UNDER THIS AGREEMENT AT YOUR OWN RISK AND “AS‑IS” WITHOUT WARRANTY OF ANY KIND. You shall input only non‑sensitive, non‑production data into the Non‑Production Instance. ServiceNow shall have no obligation or liability for or with respect to an Non‑Production Instance, including without limitation: warranty, support, reliability, backup, performance or service level, refund, service credits, loss of use or loss of data.
You shall treat your login credentials to, and the contents of (with the exception of data inserted by you), the Non‑Production Instance as confidential information and shall not disclose it to any third party. You agree to provide any required disclosures to and obtain any required consents for the transfer of your data to ServiceNow in connection with your use of the Non‑Production Instance. ServiceNow shall not be responsible for compliance with any laws applicable to you and your industry that are not generally applicable to information technology service providers. You agree that ServiceNow may collect, use and disclose quantitative data derived from the use of the Non‑Production Instance for industry analysis, benchmarking, analytics, marketing, and other business purposes. All data collected, used, and disclosed regarding your use of a Non‑Production Instance will be in aggregate form only and will not identify you.
#####  4. Store and Share
The ServiceNow Store available at [http://store.servicenow.com](http://store.servicenow.com/), the ServiceNow Publisher Portal available at [http://tpp.servicenow.com](http://tpp.servicenow.com/), and their related and successor websites (collectively, “**Store** ”), and the ServiceNow Share site available at [http://share.servicenow.com](http://share.servicenow.com/) and its related and successor websites (“**Share** ”), permit registered users, ServiceNow partners and ServiceNow to review and access Apps developed by the user and partner community. As used herein, “**App** ” shall mean a Contribution, posted by a user, a ServiceNow Technology Partner or ServiceNow, that is an application, integration, configuration, extension, update set or other material developed using, or for use in connection with, the ServiceNow Products or other ServiceNow Core Technology. Apps may be downloaded for use on the recipient’s instance or hosted by ServiceNow, and may include artifacts such as code and documentation.
You may not post Apps to the Store site unless you have entered into ServiceNow’s Technology Partner Program pursuant to a separate written agreement. Such separate agreement shall control over these Terms of Use with respect to your use of the Store to the extent that these Terms of Use are in conflict with the separate agreement.
Several types of Apps may be posted to Store and Share:
“**Shared App** ” means any App provided free of charge on the Share site. Shared Apps may be downloaded or hosted by ServiceNow in connection with the recipient’s ServiceNow Products. You may not offer paid Apps for subscription or sale on the Share site.
“**Conditional Shared App** ” means any Shared App for which a user must agree to additional or different terms and conditions (“**App Conditions** ”) as a condition to download or access the App.
“**Store App** ” means an App posted to the Store site that is available for a fee or free of charge, and subject to App Conditions.
A “**ServiceNow App** ” shall mean an App posted by any employee, agent or contractor acting on behalf of ServiceNow, and may be a ServiceNow Shared App, ServiceNow Conditional Shared App or ServiceNow Store App.
All Shared Apps and Conditional Shared Apps posted to Share, and Store Apps posted to Store, are subject to the terms of Section 5 (_Posting Apps_).
**Purchases of Store Apps**
**Payments and Subscription Term**. On the Store site, you may place a non‑cancellable and non‑refundable (except as expressly set forth herein) order to purchase access to a Store App by clicking the “purchase” button associated with that App on Store. Prices stated on Store, including discounts, are final. Except as expressly set forth in the description of a particular Store App, fees for Store Apps are invoiced at the time you place your order. Each Store App is purchased for a term of twelve (12) months, provided that you have a valid paid subscription to the ServiceNow Product(s) required to use the Store App throughout that period. In the event that your subscription to any ServiceNow Product required to use the Store App expires, you may not use the Store App until such use rights are reinstated. Your payment obligation provided in this section shall survive expiration or termination of your rights to use any ServiceNow Product required to use the Store App. Purchase of a Store App is a continuous and non‑divisible commitment for the full duration of its subscription term regardless of the invoice schedule. You may cancel your subscription upon expiration of any Store App subscription term. ServiceNow will provide advance notice of each renewal date to the contact information provided by you. Unless you cancel your subscription, Store Apps will automatically renew upon the expiration of each subscription term.
**Payments by Credit Card**. For purchases by credit card, payment and invoice shall be due upon purchase of the Store App. The credit card you provide for billing purposes will be billed on a monthly basis during the subscription term of the Store App and on any subsequent automatic renewal subscription terms.
**Purchases by Invoice**. For purchases by invoice, all payments shall be due net thirty (30) days from the date of ServiceNow’s invoice, and payments shall be invoiced and made in the currency provided in the invoice. You may issue a purchase order consistent with these Terms of Use, but a purchase order is not required. If you issue a purchase order, then it shall be for the full amount of the purchase as provided on Store, and any additional or conflicting terms appearing in a purchase order shall not amend this Agreement.
**Late Payments**. Late payments shall accrue interest at a rate of one and one‑half percent (1.5%) per month or the legal maximum interest rate, whichever is lower. If you are delinquent in payment of amounts owed hereunder, ServiceNow may give notice to you of such delinquency, following which you shall cure the delinquency within thirty (30) days from the date of ServiceNow’s written notice. If you fail to cure the delinquency or regain compliance in accordance with the paragraph below, ServiceNow may suspend your access to the Store App in addition to other rights and remedies available.
**Overuse**. ServiceNow may remotely review your use of the Store App for comparison with your rights of use, and upon ServiceNow’s written request you shall provide any reasonable assistance to verify your compliance with these Terms of Use. If ServiceNow determines that you have exceeded your permitted use of the Store App then ServiceNow will notify you and within thirty (30) days thereafter you shall either: (a) disable any unpermitted use or (b) purchase additional subscriptions commensurate with your actual use.
**Taxes**. All prices on Store are stated exclusive of all taxes, duties, levies, imposts, fines or similar governmental assessments including sales and use taxes, value‑added taxes (“**VAT** ”), goods and services taxes (“**GST** ”), excise, business, service, and similar transactional taxes imposed by any jurisdiction and the interest and penalties thereon (collectively, “**Taxes** ”). You shall be responsible for and bear Taxes associated with your purchase of, payment for, access to or use of any Store App accessible to you. Taxes shall not be deducted from the payments to us, except as required by law, in which case you shall increase the amount payable as necessary so that after making all required deductions and withholdings, we receive and retain (free from any Tax liability) an amount equal to the amount it would have received had no such deductions or withholdings been made. Each party is responsible for and shall bear taxes imposed on its net income. If you are or represent a tax‑exempt entity or claim exemption from any Taxes under these Terms of Use, you shall provide a tax exemption number and a certificate to us prior to your purchase and, after receipt of valid evidence of exemption, ServiceNow shall not charge you any Taxes from which you are exempt. If we are required to invoice or collect Taxes associated with your purchase of, payment for, access to or use of the Store App, we will issue an invoice to you including the amount of those Taxes, itemized where required by law. You shall provide to us your VAT or GST identification number(s) for (i) the country where you have established your business and/or (ii) any other country where you have a fixed establishment. You shall use the ordered Store App for your business use in the foregoing location(s) in accordance with the provided VAT or GST identification number(s). The parties’ obligations under this Section shall survive the termination or expiration of these Terms of Use.
**App Rights and Restrictions**
The following terms shall apply to your use of Apps from Store and Share, in addition to other limitations and disclaimers provided herein:
**Minimum Requirements**. You must procure separate permission from us to use the ServiceNow Products, including: (a) any specific ServiceNow Product that may be required to run an App, including, without limitation, any ServiceNow Product required to use custom applications that run on the ServiceNow Platform; and (b) any ServiceNow Product with which the App is intended to be used. If you have no Subscription Agreement with us, then you may not use Apps.
**Rights to Apps subject to App Conditions**. The user posting an App subject to App Conditions, and not ServiceNow, has sole responsibility for the terms and obligations of the App Conditions. Your access, use or download of a Conditional Shared App or Store App is subject to the App Conditions presented to you prior to your access, provided that to the extent that the App Conditions conflict with these Terms of Use, these Terms of Use shall control to the extent of such conflict. Notwithstanding any contrary term or condition in any App Conditions, you may not transfer, sublicense, distribute or otherwise provide third parties access to any App that you acquire through Store or Share. ServiceNow has no responsibility for the contents of any App Conditions.
**Rights to ServiceNow Apps**. You shall have, with respect to any purchased ServiceNow Store App, the rights and obligations applicable to “Subscription Service” under your current Subscription Agreement, subject to the disclaimers set forth in these Terms of Service. You shall have, with respect to any downloaded ServiceNow Shared App, a non‑exclusive, non‑transferable, perpetual right to copy, use, and make derivative works of the ServiceNow Shared App solely to evaluate, customize, configure or use the ServiceNow Shared App in conjunction with ServiceNow Products that you are otherwise permitted to use under a separate Subscription Agreement. Notwithstanding the foregoing, in the event that a ServiceNow Store App or ServiceNow Shared App is subject to App Conditions, such App Conditions shall apply to your use of the App. In the event of any conflict between App Conditions applicable to a ServiceNow App and these Terms of Use, the App Conditions shall govern to the extent of such conflict with respect to your use of the corresponding ServiceNow App.
**Restrictions on Use of Store and Share Contributions**. Notwithstanding any contrary term or condition in any App Conditions, you may not: (a) transfer, sublicense, distribute or otherwise provide a third‑party access an App; (b) use an App to develop a product that is operable apart from the ServiceNow platform; (c) use APIs other than the ServiceNow APIs provided on the ServiceNow website to communicate with the ServiceNow Products, or circumvent such APIs or otherwise use APIs that diminish ServiceNow’s ability to isolate errors when providing customer support; or (d) use an App other than in connection with a ServiceNow Product that you are permitted to use under a separate Subscription Agreement.
**Certification**. Certain Apps may be advertised as  _Certified_ , meaning that the App successfully passed a number of compatibility tests designated by us. The identification of an App as  _Certified_ shall not be construed as making any representation, warranty, guarantee or promise apart from those set forth in these Terms of Use, nor that a contributor’s provision of, or your use of, an App is permitted by third parties or any applicable laws and regulations.
**Testing**. The user posting an App, and not ServiceNow (with the exception of ServiceNow Apps), is the provider and grantor of access rights and has sole responsibility for the content of the corresponding App. All Apps must be thoroughly tested by the user in a testing environment before use in a production environment. You agree not to rely on any statements, claims, comments or other discussion on or through the Website by any person with respect to Apps. Except as otherwise offered in any App Conditions pertaining to an App, you are solely responsible for independently testing and validating any App before deploying it in a production environment. Accordingly, you shall not assert any claim for breach of warranty or contract or misrepresentation against any third‑party user based on the performance of an App.
**Disclaimer of Support, Indemnification and Security**. Your use of an App, or incorporation of an App (even a ServiceNow App) into any ServiceNow Product constitutes a modification or customization of that ServiceNow Product by you for purposes of any Subscription Agreement or other agreement between you and ServiceNow relating to the ServiceNow Product, and such customization or modification (or malfunction or loss of function caused thereby) shall not be subject to any warranty under a Subscription Agreement. You are not entitled to support, service credits, refunds, service level agreement or other service entitlements under any Subscription Agreement or other agreement of any kind with respect to your use of any App except as expressly granted by us in any App Conditions. Indemnification or security obligations imposed on us in a Subscription Agreement shall not apply to Apps that you implement or use in connection with a ServiceNow Product.
Except as otherwise provided in any App Conditions, the App contributor does not provide support, whether that contributor is us or a third‑party user of the Website. To create an environment in which users are encouraged to contribute materials for discussion and testing by other users, refrain from making demands for support to the originator of the content.
**Disclaimer of Contributor Liability**. You must review and thoroughly test in a non‑production environment any App prior to its use in any production instance of the ServiceNow Products. You agree that you bear all risks associated with using any App. EXCEPT FOR LIABILITY TO SERVICENOW OR AS EXPRESSLY PROVIDED OTHERWISE IN ANY APPLICABLE APP CONDITIONS, IN NO EVENT SHALL ANY CONTRIBUTOR OR SERVICENOW HAVE ANY LIABILITY OR RESPONSIBILITY HEREUNDER TO YOU OR ANY OTHER PERSON FOR ANY LOSSES OR DAMAGES WHATSOEVER ARISING OUT OF AN APP, INCLUDING BUT NOT LIMITED TO DIRECT, INDIRECT, SPECIAL, INCIDENTAL, PUNITIVE, OR CONSEQUENTIAL DAMAGES, COVER, OR DAMAGES BASED ON LOST PROFITS, DATA, OR USE, HOWEVER CAUSED AND WHETHER IN CONTRACT, IN TORT OR UNDER ANY OTHER THEORY OF LIABILITY, WHETHER OR NOT YOU HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES, AND REGARDLESS OF WHETHER SERVICENOW OR THE THIRD‑PARTY ORIGINATOR OF THE APP REVIEWED, MODERATED, COMMENTED ON OR PROMOTED SUCH APP.
**No Warranty to User**. EXCEPT AS EXPRESSLY PROVIDED OTHERWISE IN ANY APPLICABLE APP CONDITIONS, APPS ARE PROVIDED TO YOU “AS‑IS” AND “AS AVAILABLE,” WITHOUT WARRANTY OF ANY KIND. WITHOUT LIMITING THE GENERALITY OF THE FOREGOING, EACH USER OF THE WEBSITE MAKES NO REPRESENTATION, WARRANTY OR GUARANTY, EXPRESS, STATUTORY OR IMPLIED TO YOU OR ANY OTHER PERSONS TO THE RELIABILITY, USEFULNESS, COMPLETENESS, TIMELINESS, QUALITY, SUITABILITY, AVAILABILITY OR ACCURACY OF THE APP. NO USER WARRANTS THAT ALL OR ANY PORTION OF THE APP IS ERROR FREE OR WILL OPERATE WITHOUT INTERRUPTION. WITHOUT LIMITING THE FOREGOING, AND TO THE FULLEST EXTENT PERMITTED BY LAW, EACH USER SPECIFICALLY DISCLAIMS ALL STATUTORY OR OTHER W ARRANTIES INCLUDING IMPLIED WARRANTIES OF MERCHANTABILITY, TITLE OR FITNESS FOR A PARTICULAR PURPOSE OR ANY IMPLIED WARRANTIES ARISING FROM USAGE OF TRADE, COURSE OF DEALING OR COURSE OF PERFORMANCE.
ADDITIONAL DISCLAIMERS OF WARRANTY AND LIABILITY BY SERVICENOW ARE PROVIDED BELOW IN THESE TERMS OF USE WITH RESPECT TO APPS.
#####  5. Posting Apps
The terms of this Section 5 apply to any App that you post to the Website, including Store and Share, or otherwise make available to a third party.
**Grant of rights to Shared Apps**. By posting a Shared App in the form of an update set, you hereby grant to each user of Share a non‑exclusive, non‑transferable, perpetual license (to the extent of your rights in the Shared App) to copy, use, and make derivative works of the Shared App solely to evaluate, customize, configure or use the App in conjunction with ServiceNow Products that such user is otherwise permitted to use under a separate Subscription Agreement.
**Negative Impacts and Removal**. ServiceNow reserves the right to remove any posted App or terminate access to an App (including a Store App) that, in ServiceNow’s sole discretion: (a) deteriorates ServiceNow’s ability to meet its service level agreement; (b) is relevant to an obsolete version, in ServiceNow’s discretion; (c) interferes with ServiceNow’s ability to provide its commercially available products and services in accordance with ServiceNow’s standard support and service availability terms without a promptly accessible cure deemed acceptable by ServiceNow; (d) is subject to the contributor’s request for removal; (e) was contributed by a user that is not in compliance with these Terms of Use or other agreement; or (f) violates these Terms of Use.
**Separate Agreement Required**. You may not grant or purport to grant (and nothing in these Terms of Use shall be construed as granting or authorizing you to grant) any license or other right under or to any copyright or other intellectual property right of ServiceNow or any other party whose software, data, proprietary information, patentable invention or other subject matter is included in or required to use your App (regardless of whether ServiceNow or such other person licensed, permitted, encouraged or otherwise authorized you to include or use such subject matter). You shall not assert any patent right against ServiceNow or any third‑party user based on an alleged infringement that is caused in whole or part by their authorized use of any App that you created or posted to the Store.
**Third‑Party Materials**. You represent and warrant that you own or otherwise rightfully possess all intellectual property and other rights necessary to allow you to grant access to or license (as applicable) to any App that you post to the Store.
**Service Interference**. If your App interferes with our ability to provide our commercially available products and services to our customers in accordance with the support and service availability terms in the Subscription Service Guide posted at www.servicenow.com/schedules.do without a promptly accessible cure deemed acceptable by us, we may immediately discontinue your ability to make the App available to ServiceNow Customers in our sole discretion.
**Compatibility**. Any App that you create must be compatible with applicable ServiceNow Products and must not: (a) permit a user to pose as another user or multiple users to act as a single user; (b) include, send, store, or run software viruses, worms, Trojan horses, or other harmful computer code, files, scripts, agents, or programs; (c) access, copy, destroy or transmit data regarding any user or device in excess of what is described in the accompanying documentation; (d) create a denial of service; (e) violate any law or regulation of the United States, any state thereof, or other government authority; or (f) disable, exploit, hack, or otherwise interfere with any security, encryption, digital signing, digital rights management, verification, or authentication mechanisms implemented in or by the ServiceNow Products.
**Obligations Under Third‑Party Agreements**. If you have obligations to any third party (for example, under the terms and conditions of a social networking service that you choose to link to or access via your App), you and not us are responsible for your compliance with those requirements.
**Warranty to ServiceNow**. You represent, warrant and agree that: (a) your App will not violate or infringe upon the intellectual property rights or other rights of any person or entity, contain any illegal or defamatory material, or violate any laws; (b) with respect to any content contained in or provided through your App and the use of your ServiceNow Products, you have and will continue to be solely responsible for (i) securing, reporting, and maintaining all necessary rights, clearances, and consents related thereto; and (ii) paying all licensing fees, royalties, or respective shares, if any, of any monies payable hereunder to any co‑owners, co‑administrators, or licensors thereof; (c) your App conforms with the requirements of this Section 4; (d) you have complied with all of your obligations with respect to any third‑party software in your App, including, but not limited to, any notice and source code availability obligations that may be required by any applicable free or open source software (“**FOSS** ”) used by you; (e) the licensing terms for any FOSS included with your App will not purport to require ServiceNow or any ServiceNow customer to disclose or make available any of the keys, authorization codes, methods, procedures, data, or other information related to the digital signing or digital rights management mechanisms utilized as part of the ServiceNow Products, Development Tools, Store, Share or any third‑party products distributed through the ServiceNow Products; and (f) you shall not make any promise, warranty or representation on behalf of ServiceNow with respect to Apps that you post.
**Data Collection**. You and your Apps may not collect user or device data without prior user consent, and then only to provide a service or function that is directly relevant to the use of your App. You may not use analytics software in your App to collect and send device data to you or a third party. You must provide clear and complete information to your customer regarding your collection, use and disclosure of user or device data in advance of and during, that customer’s use. Furthermore, you must take appropriate steps to protect such data from unauthorized use, disclosure, or access by third parties. If a user ceases to consent or affirmatively revokes consent for your collection, use, or disclosure of his or her user or device data, you must promptly cease all such use. You may not disclose ServiceNow customer data to any third party or use such data for any purpose other than to provide to provide the customer with the functionality of your App. You shall maintain and use all ServiceNow customer data in accordance with privacy and security reasonably adequate to preserve its confidentiality and security and all applicable data privacy and data security laws and regulations.
**Privacy Policy**. You agree that any Personal Information that you collect from a third party in relation to your App will be collected, processed, transmitted, maintained, and used in compliance with: (a) your agreement with such user; (b) all applicable laws; and (c) a privacy policy that you conspicuously make available to such user that governs your collection of Personal Information from such user (your “**Privacy Policy** ”). You shall comply with the terms and conditions of your Privacy Policy and employ reasonable measures to ensure that unauthorized third parties are unable to access such Personal Information or other end user data. You are solely responsible for your interactions (including any disputes) with each user of your App. Neither you nor your App may perform any functions or link to any content, services, information, or data, or use any robot, spider, site search, or other retrieval application or device to scrape, mine, retrieve, cache, analyze, or index any software, user data, Personal Information, or other information related to operation or use of the ServiceNow Products, except to the limited extent necessary to provide your App and your related services to end users (or to demonstrate ServiceNow Products to prospective users with their permission) and in accordance with your Privacy Policy. “**Personal Information** ” means any and all information pertaining to a specific person, including, but not limited to, a person’s name, e‑mail address, mailing address, telephone number, credit card number, or persistent identifier (such as an identification number held in a cookie) which is associated with a person’s individually identifiable information. Personal Information also includes information that can, together with the other information collected or to be collected, identify a specific individual, even if such information cannot, by itself, identify a specific individual.
**Security Review**. We, or a third party selected by us, may conduct a security review of any App, including without limitation, information requests to the contributor, interviews, security testing, network testing, and vulnerability threat assessment. You agree to reasonably cooperate with such testing, and further you agree that ServiceNow, its agents or contractors conducting the testing shall bear no responsibility for any adverse effects on the operation of your App or business. Any nonpublic information obtained by us during any security test shall be treated as your confidential information.
**Regulatory Compliance**. You represent, warrant and agree that you will comply with any applicable regulatory requirements, including full compliance with all applicable laws, regulations, and policies related to the development, marketing, sale, and distribution of your App, and the laws, regulations and policies of any other applicable regulatory bodies in any countries or territories where you use, sell, distribute or otherwise make your App available. However, you agree that you will not seek any regulatory marketing permission or make any determinations that may result in the ServiceNow Product being deemed regulated or that may impose any obligations or limitations on us. Upon our request, you agree to promptly provide any such clearance documentation to support the marketing of your App.
**Indemnity**. In addition to your indemnification obligation to ServiceNow provided below, you agree to indemnify and hold each other user and its officers, agents, employees, subsidiaries and affiliates harmless from any claims, demands, liabilities, losses, damages, costs and expenses (including, without limitation, reasonable attorneys’ fees) arising from any claim made by any third party arising out of the Apps posted by you, including but not limited to claims that such App or its use violates any rights of a third party.
#####  6. Intellectual Property
**Website**
The Website in its entirety including the, Website Content and is owned by ServiceNow or our licensors and is protected by United States and international laws regarding copyrights, patents, trademarks, trade secrets and other intellectual property or proprietary rights. You are permitted to use the Website only for legitimate business purposes related to your role as a current or prospective customer, developer, partner, supplier or distributor of ServiceNow. You shall not copy, modify, create derivative works of, publicly display or perform, republish, download or store, or transmit any Website Content without ServiceNow’s express prior written consent or except as expressly provided in these Terms of Use.
**ServiceNow Core Technology**
As between ServiceNow and you, all rights, title, and interest in and to all intellectual property rights in the ServiceNow Core Technology are owned exclusively by ServiceNow notwithstanding any other provision in these Terms of Use. Except as otherwise expressly provided in these Terms of Use, ServiceNow reserves all rights in the ServiceNow Core Technology and does not grant you any rights, express or implied or by estoppel. As used herein, “**ServiceNow Core Technology** ” means: (a) the Non‑Production Instance, Development Tools, Documentation and ServiceNow technology and methodologies (including, without limitation, products, software tools, hardware designs, algorithms, templates, software (in source and object forms), architecture, class libraries, objects and documentation) existing as of the Effective Date; (b) updates, upgrades, improvements, configurations, extensions, and derivative works of the foregoing, however made, and related technical or end user documentation or manuals; and (c) intellectual property anywhere in the world relating to the foregoing.
**User Technology**
As between you and ServiceNow, you shall retain all rights, title, and interest in and to its intellectual property rights in the electronic data uploaded by you (excluding ServiceNow Core Technology), and User Technology. You hereby grant to ServiceNow a perpetual, irrevocable, royalty‑free, fully‑paid, sublicensable, transferable, non‑exclusive, worldwide license to copy, distribute, modify, make derivative works of, publicly display, publicly perform, make, use, sell, translate and disclose to third parties any User Technology or data uploaded by you in the Non‑Production Instance solely for the purpose of providing the Non‑Production Instance to you. As used herein, “**User Technology** ” means software, methodologies, templates, business processes, documentation or other material authored, invented or otherwise created or licensed (other than by or from ServiceNow) by you using or for use with the Non‑Production Instance, excluding the ServiceNow Core Technology.
**ServiceNow Trademarks**
ServiceNow, the ServiceNow logo, Now, and other ServiceNow marks are trademarks and/or registered trademarks of ServiceNow, Inc., or its affiliates or licensors, in the United States and/or other countries. Other company and product names may be trademarks of the respective companies with which they are associated. Reference the [ServiceNow Trademark and Copyright Guidelines](https://www.servicenow.com/trademarks.html) for more information regarding ServiceNow trademarks.
**Development Tools**
Development Tools available for download are the copyrighted works of ServiceNow and/or third‑party providers. Subject to these Terms of Use, we grant you a limited, revocable, non‑transferable, non‑exclusive and non‑sublicensable license to reproduce and use the Development Tools for your own internal business use, solely to evaluate ServiceNow Products. If there are license terms accompanying any specific Development Tool, such accompanying license terms shall control over these Terms of Use. ServiceNow has no obligation to provide support services for, or updates to, the Development Tools.
If you use Development Tools to create software that communicates or otherwise interoperates with the ServiceNow Products, you agree that such software will exclusively use the ServiceNow APIs provided with the Development Tools to communicate with the ServiceNow Products. You agree that such software shall not circumvent these APIs or otherwise use APIs that diminish ServiceNow’s ability to isolate errors when providing customer support. Development Tools are proprietary information of ServiceNow. You shall not distribute Development Tools to any third party and will not use the Development Tools to develop any software product that is operable apart from the ServiceNow platform.
**Documentation**
The Documentation available on the Website is the copyrighted work of ServiceNow and/or third‑party providers. Subject to these Terms of Use, we grant you a limited, revocable, non‑transferable, non‑exclusive and non‑sublicensable license to make a reasonable number of copies of the Documentation for your internal business use in connection with your separately authorized use of ServiceNow Products. No right to sublicense or distribute the Documentation is granted herein.
**User Contributions**
No rights are granted to you with respect to User Contributions (not including Apps, which are treated as described above) other than the limited, personal, non‑exclusive license to reproduce User Contributions as necessary to display the User Contributions on a machine that you use to interact with the Website.
**Third Party Content**
Third‑party materials and free and open source software (not including Apps) (“**FOSS** ”) provided by us to you may be accompanied by licensing terms, in which case such licensing terms shall govern your use of that third‑party software or FOSS. Mention of third parties and third‑party products in any materials, advertising, promotions or coupons provided to you is for informational purposes only and constitutes neither an endorsement nor a recommendation. All third‑party product specifications and descriptions are supplied by the respective vendor or supplier, and ServiceNow shall have no responsibility with regard to the selection, performance or use of such vendors or products. To the extent you access or use such software, all understandings, agreements or warranties, if any, shall be directly between the vendor and you.
**Restrictions**
No right, title or interest in or to the Website including Website Content and Contributions or ServiceNow Core Technology, is transferred to you.
There are no implied licenses under these Terms of Use. ServiceNow reserves all rights not expressly granted to you herein. Any use of the Website not expressly permitted by these Terms of Use is a breach of these Terms of Use and may violate copyright, trademark and other laws.
ServiceNow Core Technology is licensed and not sold even if for convenience ServiceNow makes reference to words such as sale or purchase.
You shall not (and shall not permit others to) do any do any of the following with respect to the Website or ServiceNow Core Technology: (a) license, sublicense, sell, resell, rent, lease, transfer, distribute or time share it or otherwise make any of it available for access by third parties, including any derivative works of ServiceNow Core Technology irrespective of which party authors such derivative works; (b) use it on a production basis or with production data or use it to provide services to others including services of implementation, customization or configuration of the Subscription Service; (c) disassemble, decompile or reverse engineer it, particularly for the purpose of developing any product or services competitive with the Subscription Service generally; (d) subject to the preceding clause, use or access it for the purpose of developing products or service competitive with the platform component of the Subscription Service (competitive applications, however, are permitted); (e) copy, create derivative works of, or otherwise modify it, except as expressly permitted hereunder; (f) disrupt its security, integrity or operation; (g) remove or modify a copyright or other proprietary rights notice in it; (h) use it to reproduce, distribute, display, store, transmit or use material or content protected by copyright or other intellectual property right (including the rights of publicity or privacy) without first obtaining the permission of the owner; (i) use it to damage the property of another; (j) use it in any manner which violates any applicable law or regulation; (k) use it in a manner that temporarily or permanently alters, erases, removes, copies, modifies, halts or disables any ServiceNow or third‑party data, software or network (not including modifications to the Configurable Elements or any data uploaded into the Subscription Service by Participant) without authorization; (l) use it to create, use, send, store or run viruses or other harmful computer code; (m) use it in any manner that disables, hacks or interferes with any security, digital signing, digital rights management, verification or authentication mechanisms; or (n) use it in any manner that, in ServiceNow’s reasonable judgment, circumvents the ordinary use or operation of the Subscription Service or APIs, disrupts ServiceNow’s pricing structure or ability to provide services or support to Customers, or allows any party to access ServiceNow Technology in excess of such party’s authorized or normally intended use.
Before Participant exercises any of the foregoing actions that Participant believes it is entitled to based on mandatory law, Participant shall provide ServiceNow with thirty (30) days prior written notice at legalnotices@servicenow.com, or, if applicable law or the relevant court order does not allow for thirty (30) days’ notice, the maximum amount of notice allowable, and provide all reasonably requested information to allow ServiceNow to assess Participant’s claim and, at ServiceNow’s sole discretion, to provide alternatives that reduce any adverse impact on ServiceNow’s intellectual property or other rights.
Please contact ServiceNow if you need to make use of ServiceNow Core Technology that is not permitted under these Terms of Use. Partner programs and commercial end user agreements may be available to meet your needs.
If you enter into a separate agreement with ServiceNow that provides additional or different license terms with respect to ServiceNow Core Technology, including a Master Ordering Agreement, Master Subscription Services Agreement, Developer Agreement, or Technology Partner Agreement, then the terms of that separate agreement shall control over these Terms of Use with respect to such ServiceNow Core Technology.
#####  7. Linking
**Linking to the Website**
You may link to our homepage, provided you do so in a way that is fair and legal and does not damage our reputation or take advantage of it, but you must not establish a link in such a way as to suggest any form of association, approval or endorsement on our part where none exists. You are prohibited from linking to any other page of the Website without our express written permission. We reserve the right to withdraw linking permission without notice. The Website must not be framed on any other site, nor may you create a link to any part of the Website other than the homepage. You must not establish a link from any website that is not owned by you. You agree to cooperate with us in stopping any unauthorized framing or linking.
**Links from the Website**
If the Website contains links to other sites and resources provided by third parties, these links are provided for your convenience only. This includes links from advertisers, including banner advertisements. We have no control over the contents of those sites or resources, and accept no responsibility for them or for any loss or damage that may arise from your use of them. If you decide to access any of the third‑party websites linked to this Website, you do so entirely at your own risk and subject to the applicable terms and conditions of use for such websites.
#####  8. Monitoring, Enforcement and Feedback
ServiceNow has the right but not the obligation to:
  * Remove or refuse to post any User Contribution (including any App), and/or terminate your access to all or part of the Website for any reason or no reason, in our sole discretion, including without limitation any violation of these Terms of Use or the Privacy Policy.
  * Disclose your identity to any third party who claims that material posted by you violates their rights, including their intellectual property rights or their right to privacy.
  * Take appropriate legal action, including without limitation, referral to law enforcement, for any illegal or unauthorized use of the Website.


Without limiting the foregoing, ServiceNow has the right to fully cooperate with any law enforcement authorities or court order requesting or directing us to disclose the identity of anyone posting any materials on or through the Website. YOU WAIVE AND HOLD SERVICENOW HARMLESS FROM ANY CLAIMS RESULTING FROM ANY ACTION TAKEN BY SERVICENOW DURING OR AS A RESULT OF ITS INVESTIGATIONS AND FROM ANY ACTIONS TAKEN AS A CONSEQUENCE OF INVESTIGATIONS BY EITHER SERVICENOW OR LAW ENFORCEMENT AUTHORITIES.
ServiceNow can neither review all material before it is posted on the Website nor ensure prompt removal of objectionable material after it has been posted and assumes no liability for any action or inaction regarding transmissions, communications or content provided by any user or third parties. We have no liability or responsibility to anyone for performance or nonperformance of the activities described in this paragraph.
**Feedback & Suggestions**
ServiceNow shall have a perpetual, irrevocable, royalty‑free, fully‑paid, sublicensable, transferable, non‑exclusive, worldwide license to make, use, sell, offer for sale, import or otherwise use or commercially exploit for any purpose, any feedback, comments, suggestions, communications, and requests for improvements or enhancements relating to the Website and the ServiceNow Products.
#####  9. Legal Considerations
**Confidentiality**
You agree that the configuration and information contained in a Non‑Production Instance, Apps and any information provided to you in connection with a ServiceNow event will be considered and referred to as “**ServiceNow Confidential Information** ”). Notwithstanding the foregoing, ServiceNow Confidential Information shall not include: (a) information that is generally and legitimately available to the public through no fault or breach of yours; (b) information that is generally made available to the public by us; (c) information that is independently developed by you without the use of any ServiceNow Confidential Information; (d) information that was rightfully obtained from a third party who had the right to transfer or disclose it to you without limitation; or (e) any third‑party software and/or documentation provided to you by us and accompanied by licensing terms that do not impose confidentiality obligations on the use or disclosure of such software and/or documentation.
Unless otherwise expressly agreed or permitted in writing by ServiceNow, you agree not to disclose, publish, or disseminate any ServiceNow Confidential Information to anyone. You agree not to use ServiceNow Confidential Information in any way, including, without limitation, for your own or any third party’s benefit without the prior written approval of an authorized representative of ServiceNow in each instance. You further agree to take reasonable precautions to prevent any unauthorized use, disclosure, publication, or dissemination of ServiceNow Confidential Information. You acknowledge that unauthorized disclosure or use of ServiceNow Confidential Information could cause irreparable harm and significant injury to ServiceNow that may be difficult to ascertain. Accordingly, you agree that we will have the right to seek immediate injunctive relief to enforce your obligations under this Agreement in addition to any other rights and remedies we may have. If you are required by law, regulation or pursuant to the valid binding order of a court of competent jurisdiction to disclose ServiceNow Confidential Information, you may make such disclosure, but only if you have notified us before making such disclosure and have used commercially reasonable efforts to limit the disclosure and to seek confidential, protective treatment of such information. A disclosure pursuant to the previous sentence will not relieve you of your obligations to hold such information as ServiceNow Confidential Information.
**Paid Content**
Certain parts of the Website may grant you access to certain proprietary content (including, without limitation, training modules, video presentations and audio recordings) that we may make available to you from time to time for a separate fee (“**Paid Content** ”). Paid Content shall be considered ServiceNow Confidential Information, unless otherwise agreed or permitted in writing by ServiceNow. You may not share the Paid Content with anyone, including, without limitation, employees and contractors working for the same entity as you. Subject to these terms and conditions, we grant you a non‑exclusive, non‑transferable, personal license to access and use the Paid Content upon your purchase, provided that you may only download one (1) copy of the Paid Content and such download must be completed within the time period specified by us for such download. Except as expressly permitted by us, you shall not modify, translate, reproduce, distribute, or create derivative works of the Paid Content or any part thereof. You shall not sell, sublicense, rent, lease, loan, assign or otherwise transfer any rights in the Paid Content. We and/or our licensor(s) retain ownership of the Paid Content itself and any copies or portions thereof. The Paid Content is licensed, not sold, to you by us for use only under this Agreement, and we reserve all rights not expressly granted to you. Your rights under this license to use and access the Paid Content will terminate automatically without notice from ServiceNow if you fail to comply with any of these provisions.
**Copyright Infringement**
We will respond to notices of alleged copyright infringement that comply with applicable law. If you believe any materials accessible on or from the Website infringe your copyright, you may request removal of those materials (or access thereto) from the Website by submitting written notification (a “**DCMA Notice** ”) to our copyright agent (designated below) in accordance with the Online Copyright Infringement Liability Limitation Act of the Digital Millennium Copyright Act (17 U.S.C. § 512) (“**DMCA** ”)
Our designated Copyright Agent to receive DMCA Notices is:
ServiceNow, Inc.
Attn: Legal Department, Copyright Agent
2225 Lawson Lane, Santa Clara, CA 95054, USA
Copy to legalnotices@servicenow.com
If you fail to comply with all of the requirements of Section 512(c)(3) of the DMCA, your DMCA Notice may not be effective.
If you believe that material you posted on the site was removed or access to it was disabled by mistake or misidentification, you may file a counter‑notification with us by submitting written notification to our copyright agent (identified above) pursuant to the DMCA.
It is the policy of ServiceNow to terminate the user accounts of infringers.
**Regional Legal Considerations**
The owner of the Website is based in the state of California in the United States. The Website can be accessed from countries around the world. Access to the Website may not be legal by certain persons or in certain countries. If you access the Website from outside the United States, you do so on your own initiative and are responsible for compliance with local laws. Access to the Website from territories where the Website or any of its services or products are illegal is prohibited. You acknowledge that you remain responsible at all times for your compliance with U.S. and all applicable export and related statutes and regulations.
**Disclaimer of Warranties**
ServiceNow cannot and does not promise or warrant that any aspect of the Website, including the Community Services, Documentation, Development Tools, Store, Apps, or any other Website Content is free of viruses or other destructive code. You are responsible for implementing sufficient procedures and checkpoints to satisfy your particular requirements for anti‑virus protection and accuracy of data input and output, and for maintaining a means external to our site for any reconstruction of any lost data. SERVICENOW WILL NOT BE LIABLE FOR ANY LOSS OR DAMAGE CAUSED BY A DISTRIBUTED DENIAL‑OF‑SERVICE ATTACK, VIRUSES OR OTHER TECHNOLOGICALLY HARMFUL MATERIAL THAT MAY INFECT YOUR COMPUTER EQUIPMENT, COMPUTER PROGRAMS, DATA OR OTHER PROPRIETARY MATERIAL DUE TO YOUR USE OF THE WEBSITE OR ANY SERVICES OR ITEMS OBTAINED THROUGH THE WEBSITE OR TO YOUR DOWNLOADING OF ANY MATERIAL POSTED ON IT, OR ON ANY WEBSITE LINKED TO IT.
AS BETWEEN YOU AND SERVICENOW, YOUR USE OF THE WEBSITE AND NON‑PRODUCTION INSTANCES, INCLUDING COMMUNITY SERVICES, USER CONTRIBUTIONS, APPS, DEVELOPMENT TOOLS, DOCUMENTATION AND ANY OTHER WEBSITE CONTENT, AND ANY SERVICES OR ITEMS OBTAINED THROUGH THE WEBSITE, IS AT YOUR OWN RISK. THE WEBSITE, INCLUDING THE WEBSITE CONTENT, NON‑PRODUCTION INSTANCES AND ANY SERVICES OR ITEMS OBTAINED THROUGH THE WEBSITE, ARE PROVIDED TO YOU BY SERVICENOW ON AN "AS IS" AND "AS AVAILABLE" BASIS, WITHOUT ANY WARRANTIES OF ANY KIND, EITHER EXPRESS OR IMPLIED. NEITHER SERVICENOW NOR ANY PERSON ASSOCIATED WITH SERVICENOW MAKES ANY WARRANTY OR REPRESENTATION WITH RESPECT TO THE COMPLETENESS, SECURITY, RELIABILITY, QUALITY, SUITABILITY, ACCURACY OR AVAILABILITY OF THE WEBSITE. WITHOUT LIMITING THE FOREGOING, NEITHER SERVICENOW NOR ANYONE ASSOCIATED WITH SERVICENOW REPRESENTS OR WARRANTS THAT THE WEBSITE, INCLUDING THE WEBSITE CONTENT OR ANY SERVICES OR MATERIALS OBTAINED THROUGH THE WEBSITE, WILL BE ACCURATE, RELIABLE, ERROR‑FREE OR UNINTERRUPTED, THAT DEFECTS WILL BE CORRECTED, THAT OUR SITE OR THE SERVER THAT MAKES IT AVAILABLE ARE FREE OF VIRUSES OR OTHER HARMFUL COMPONENTS OR THAT THE WEBSITE OR ANY SERVICES OR ITEMS OBTAINED THROUGH THE WEBSITE WILL OTHERWISE MEET YOUR NEEDS OR EXPECTATIONS.
SERVICENOW HEREBY DISCLAIMS ALL WARRANTIES OF ANY KIND, EITHER EXPRESS OR IMPLIED, STATUTORY OR OTHERWISE, WITH RESPECT TO THE WEBSITE, THE WEBSITE CONTENT, NON‑PRODUCTION INSTANCES OR ANY SERVICES OR ITEMS OBTAIN THROUGH THE WEBSITE, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OF MERCHANTABILITY, NON‑INFRINGEMENT AND FITNESS FOR PARTICULAR PURPOSE.
THE FOREGOING DOES NOT AFFECT ANY WARRANTIES WHICH CANNOT BE EXCLUDED OR LIMITED UNDER APPLICABLE LAW. YOU MAY RECEIVE WARRANTIES FROM THE CONTRIBUTOR OF AN APP PURSUANT TO THE APP CONDITIONS UNDER WHICH SUCH APP IS PROVIDED TO YOU; HOWEVER, SERVICENOW SHALL HAVE NO LIABILITY TO YOU WITH RESPECT TO SUCH WARRANTIES OR ANY OTHER TERM IN THE APP CONDITIONS.
**Limitation of Liability**
EXCEPT TO THE EXTENT THAT A DISCLAIMER OF LIABILITY IS PROHIBITED UNDER APPLICABLE LAW, IN NO EVENT WILL SERVICENOW, ITS AFFILIATES AND ITS LICENSORS, SERVICE PROVIDERS, EMPLOYEES, AGENTS, OFFICERS AND DIRECTORS BE LIABLE FOR DAMAGES OF ANY KIND, UNDER ANY LEGAL THEORY, ARISING OUT OF OR IN CONNECTION WITH YOUR USE, OR INABILITY TO USE, THE WEBSITE, INCLUDING ANY COMMUNITY SERVICES, NON‑PRODUCTION INSTANCE, USER CONTRIBUTIONS, APPS, WEBSITE CONTENT OR SERVICES OR MATERIALS MADE AVAILABLE THROUGH THE WEBSITE, INCLUDING ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR PUNITIVE DAMAGES, INCLUDING BUT NOT LIMITED TO, PERSONAL INJURY, PAIN AND SUFFERING, EMOTIONAL DISTRESS, LOSS OF REVENUE, LOSS OF PROFITS, LOSS OF BUSINESS OR ANTICIPATED SAVINGS, LOSS OF USE, LOSS OF GOODWILL, LOSS OF DATA, AND WHETHER CAUSED BY TORT (INCLUDING NEGLIGENCE), BREACH OF CONTRACT OR OTHERWISE, EVEN IF FORESEEABLE.
**Indemnification**
To the maximum extent permitted by applicable laws, you agree to defend, indemnify and hold us, our affiliates and licensors and their respective officers, directors, employees, contractors, agents, licensors and suppliers harmless from and against any claims, liabilities, damages, judgments, awards, losses, costs, expenses or fees (including reasonable attorneys' fees and other costs of defense) resulting from your violation of these Terms of Use or your use of the Website, user data, Development Tools and Non‑Production Instances (including anything that you develop using the Development Tools and Non‑Production Instances), including, without limitation, any use of the Website's content, unpaid tax liability, services and products other than as expressly authorized in these Terms of Use or your use of any information obtained from the Website. We will be entitled, at our sole expense, to participate in the defense and settlement of the claim or action with counsel of our choosing. You may not settle any claims without our prior written consent (which will not be unreasonably withheld). You shall have no obligation to indemnify ServiceNow against a claim to the extent that a claim is based on the alleged infringement of intellectual property rights by the ServiceNow Products (independent of your App or other products or services of yours).
**Export Restrictions**
You may not access, download, use or export materials posted to the Website in violation of U.S. export laws or regulations or in violation of any other applicable export or import laws or regulations. You agree to comply with all export laws and restrictions and regulations of any United States or foreign agency or authority.
You acknowledge that the Non‑Production Instances, Apps, Documentation and Development Tools are subject to the U.S. Export Administration Regulations (the “**EAR** ”) and you shall comply with the EAR. Without limiting the foregoing, you represent and warrant that: (a) you are not located in, and shall not use the Documentation and Development Tools from, any country that is subject to U.S. export restrictions (currently including, but not necessarily limited to, Cuba, Iran, North Korea, Sudan and Syria); (b) you shall not use the Documentation and Development Tools in the design, development or production of nuclear, chemical or biological weapons, or rocket systems, space launch vehicles, sounding rockets or unmanned air vehicle systems; and (iii) you are not prohibited from participating in U.S. export transactions by any federal agency of the U.S. government. In addition, you are responsible for complying with any local laws that may impact your right to import, export or use the Documentation and Development Tools.
**U.S. Government Rights**
All ServiceNow software is commercial computer software and all services are commercial items. “**Commercial computer software** ” has the meaning set forth in Federal Acquisition Regulation (“**FAR** ”) 2.101 for civilian agency purchases and the Department of Defense (“**DOD** ”) FAR Supplement (“**DFARS** ”) 252.227‑7014(a)(1) for defense agency purchases. If the software is licensed or the services are acquired by or on behalf of a civilian agency, We provide the commercial computer software and/or commercial computer software documentation and other technical data subject to the terms of these Terms of Use as required in FAR 12.212 (Computer Software) and FAR 12.211 (Technical Data) and their successors. If the software is licensed or the services are acquired by or on behalf of any agency within the DOD, we provide the commercial computer software and/or commercial computer software documentation and other technical data subject to the terms of these Terms of Use as specified in DFARS 227.7202‑3 and its successors. Only if this is a DOD prime contract or DOD subcontract, the Government acquires additional rights in technical data as set forth in DFARS 252.227‑7015. This U.S. Government Rights clause is in lieu of, and supersedes, any other FAR, DFARS or other clause or provision that addresses Government rights in computer software or technical data.
**Waiver and Severability**
No waiver of these Terms of Use by us shall be deemed a further or continuing waiver of such term or condition or any other term or condition, and any failure of ours to assert a right or provision under these Terms of Use shall not constitute a waiver of such right or provision.
If any provision of these Terms of Use is held by a court of competent jurisdiction to be invalid, illegal or unenforceable for any reason, such provision shall be eliminated or limited to the minimum extent such that the remaining provisions of the Terms of Use will continue in full force and effect.
**Third Party Beneficiaries**
There are no third‑party beneficiaries to these Terms of Use, except that other users of the Website shall be third‑party beneficiaries of provisions of Section 4 (_Store and Share_) herein in which you promise not to assert claims for breach of warranty, breach of contract, patent infringement, or misrepresentation against any third‑party user based on the use or performance of a App.
**Classification of Website and ServiceNow Products**
In the event of a dispute, the categorization of any subject matter as either the Website or a ServiceNow Product shall be made by ServiceNow in its sole discretion, and ServiceNow may reclassify as a ServiceNow Product subject matter previously included in the Website.
**Termination**
ServiceNow may terminate these Terms of Use at any time for any reason by giving you written notice, and all licenses, permissions and other rights granted to you hereunder shall immediately terminate (including the license rights granted by third parties under Section 4 (_Store and Share_) herein to permit you to user their Apps). Notwithstanding the termination of these Terms of Use for any reason, Sections 6 (_Intellectual Property_) and 9 (_Legal Considerations_) herein shall survive.
**Governing Law and Jurisdiction**
These Terms of Use and any dispute or claim arising out of, or related to, them, their subject matter or their formation (in each case, including non‑contractual disputes or claims) shall be governed by and construed in accordance with the internal laws of the State of California in the United States without giving effect to any choice or conflict of laws provision or rule (whether of the State of California or any other jurisdiction).
Any legal suit, action or proceeding arising out of, or related to, these Terms of Use or the Website shall be instituted exclusively in the federal courts of the United States or the courts of the State of California, in each case located in the Santa Clara, California although we retain the right to bring any suit, action or proceeding against you for breach of these Terms of Use in your country of residence or any other relevant country. You hereby irrevocably waive any and all objections to the exercise of jurisdiction over you by such courts and to venue in such courts.
**Entire Agreement**
The Terms of Use and our Privacy Policy constitute the sole and entire agreement between you and us with respect to the Website and supersede all prior and contemporaneous understandings, agreements, representations and warranties, both written and oral, with respect to the Website. For the avoidance of doubt, these Terms of Use do not supersede any Subscription Agreement or other agreement pursuant to which you have been granted the right to use or access a ServiceNow Product, except to the extent that these Terms of Use provide that Apps or other Website Content are not subject to warranty or entitled to support, service credits, refunds, or other service entitlements under a Subscription Agreement.
© ServiceNow, Inc. All rights reserved.
undefined
Check Box
Watch Demos
Form fields with an asterisk (*) are required.
Incredible companies work with ServiceNow
###  ![ServiceNow logo](https://www.servicenow.com/content/dam/servicenow-assets/public/en-us/images/global-nav/images/logo/1024-up.svg) The world works with ServiceNow™
[ ](https://twitter.com/servicenow) [ ](https://www.youtube.com/user/servicenowinc) [ ](https://www.linkedin.com/company/servicenow) [ ](https://www.facebook.com/servicenow) [ ](https://www.instagram.com/servicenow/) [ ](https://www.tiktok.com/@servicenow)
  * United States - Global
Americas
    * [ United States - Global ](https://www.servicenow.com/lpdem/demonow-all.html)
    * [ Brasil - Português ](https://www.servicenow.com/br/lpdem/demonow-all.html)
    * [ Canada - Français ](https://www.servicenow.com/fr-ca/lpdem/demonow-all.html)
    * [ América Latina – Español ](https://www.servicenow.com/latam/lpdem/demonow-all.html)
Asia, Pacific, and Japan
    * [ 日本 - 日本語 ](https://www.servicenow.com/jp/lpdem/demonow-all.html)
    * [ 한국 - 한국어 ](https://www.servicenow.com/kr/lpdem/demonow-all.html)
    * [ Australia/NZ - English ](https://www.servicenow.com/au/lpdem/demonow-all.html)
    * [ India - English ](https://www.servicenow.com/in/lpdem/demonow-all.html)
Europe, Middle East, and Africa
    * [ United Kingdom - English ](https://www.servicenow.com/uk/lpdem/demonow-all.html)
    * [ DACH - Deutsch ](https://www.servicenow.com/de/lpdem/demonow-all.html)
    * [ France - Français ](https://www.servicenow.com/fr/lpdem/demonow-all.html)
    * [ Nederland - Nederlands ](https://www.servicenow.com/nl/lpdem/demonow-all.html)
    * [ España - Español ](https://www.servicenow.com/es/lpdem/demonow-all.html)
    * [ Italia - Italiano ](https://www.servicenow.com/it/lpdem/demonow-all.html)
  * [ Site terms ](https://www.servicenow.com/terms-of-use.html)
  * [ GDPR ](https://www.servicenow.com/company/trust/privacy/gdpr.html)
  * [ Privacy statement ](https://www.servicenow.com/privacy-statement.html)
  * [ Your privacy choices ](https://www.servicenow.com/privacy-preferences.html)
  * [ Cookie policy ](https://www.servicenow.com/cookie-policy.html)
  * [ Cookie preferences ](https://www.servicenow.com/lpdem/demonow-all.html)
  * [ Sitemap ](https://www.servicenow.com/sitemap.html)
  * [ Business continuity ](https://www.servicenow.com/content/dam/servicenow-assets/public/en-us/doc-type/public-document/servicenow-business-continuity-faq.pdf)
  * [ Accessibility ](https://www.servicenow.com/accessibility-statement.html)
  * [Website feedback](javascript:void\(0\);)
  * © 2026 ServiceNow. All rights reserved.


We use cookies on this site to improve your browsing experience, analyze individualized usage and website traffic, tailor content to your preferences, and make your interactions with our website more meaningful. To learn more about the cookies we use and how you can change your preferences, please read our [Cookie Policy](https://www.servicenow.com/cookie-policy.html) and visit our Cookie Preference Manager. By clicking “Accept and Proceed,” closing this banner or continuing to browse this site, you consent to the use of cookies.
Accept and Proceed
![](https://id.rlcdn.com/464526.gif)
![](https://bat.bing.com/action/0?ti=150000185&Ver=2&mid=6d439189-4e55-4de2-8e1d-c211f2107cda&bo=2&sid=bdde084013ad11f1a28e5b96e01255d6&vid=bdde9e6013ad11f19e4327aec34e57fe&vids=0&msclkid=N&pi=918639831&lg=en-US&sw=1080&sh=600&sc=24&tl=ServiceNow%20Demo%20-%20ServiceNow&kw=All%20BU&p=https%3A%2F%2Fwww.servicenow.com%2Flpdem%2Fdemonow-all.html&r=&lt=1231&evt=pageLoad&sv=2&asc=G&cdb=AQAS&rn=642312)
![](https://pt.ispot.tv/v2/TC-8010-2.gif?app=web&type=Visit)![](https://cdn.bizible.com/ipv?_biz_r=&_biz_h=800054037&_biz_u=c8cd2b62188748f19023a5c5b22cefc0&_biz_l=https%3A%2F%2Fwww.servicenow.com%2Flpdem%2Fdemonow-all.html&_biz_t=1772177308799&_biz_i=ServiceNow%20Demo%20-%20ServiceNow&_biz_n=40&rnd=242539&cdn_o=a&_biz_z=1772177308799)
